/**
 * Database Management API
 * Use the Database Management API to perform tasks such as obtaining performance and resource usage metrics
for a fleet of Managed Databases or a specific Managed Database, creating Managed Database Groups, and
running a SQL job on a Managed Database or Managed Database Group.

 * OpenAPI spec version: 20201101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { DbManagementWaiter } from "./dbmanagement-waiter";
export declare enum DbManagementApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class DbManagementClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DbManagementWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DbManagementWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DbManagementWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DbManagementWaiter;
    /**
     * Adds a Managed Database to a specific Managed Database Group.
     * After the database is added, it will be included in the
     * management activities performed on the Managed Database Group.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddManagedDatabaseToManagedDatabaseGroupRequest
     * @return AddManagedDatabaseToManagedDatabaseGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/AddManagedDatabaseToManagedDatabaseGroup.ts.html |here} to see how to use AddManagedDatabaseToManagedDatabaseGroup API.
     */
    addManagedDatabaseToManagedDatabaseGroup(addManagedDatabaseToManagedDatabaseGroupRequest: requests.AddManagedDatabaseToManagedDatabaseGroupRequest): Promise<responses.AddManagedDatabaseToManagedDatabaseGroupResponse>;
    /**
       * Changes database parameter values. There are two kinds of database
  * parameters:
  * <p>
  - Dynamic parameters: They can be changed for the current Oracle
  * Database instance. The changes take effect immediately.
  * - Static parameters: They cannot be changed for the current instance.
  * You must change these parameters and then restart the database before
  * changes take effect.
  * <p>
  **Note:** If the instance is started using a text initialization
  * parameter file, the parameter changes are applicable only for the
  * current instance. You must update them manually to be passed to
  * a future instance.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ChangeDatabaseParametersRequest
       * @return ChangeDatabaseParametersResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ChangeDatabaseParameters.ts.html |here} to see how to use ChangeDatabaseParameters API.
       */
    changeDatabaseParameters(changeDatabaseParametersRequest: requests.ChangeDatabaseParametersRequest): Promise<responses.ChangeDatabaseParametersResponse>;
    /**
     * Moves the Database Management private endpoint and its dependent resources to the specified compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeDbManagementPrivateEndpointCompartmentRequest
     * @return ChangeDbManagementPrivateEndpointCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ChangeDbManagementPrivateEndpointCompartment.ts.html |here} to see how to use ChangeDbManagementPrivateEndpointCompartment API.
     */
    changeDbManagementPrivateEndpointCompartment(changeDbManagementPrivateEndpointCompartmentRequest: requests.ChangeDbManagementPrivateEndpointCompartmentRequest): Promise<responses.ChangeDbManagementPrivateEndpointCompartmentResponse>;
    /**
     * Moves a job.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeJobCompartmentRequest
     * @return ChangeJobCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ChangeJobCompartment.ts.html |here} to see how to use ChangeJobCompartment API.
     */
    changeJobCompartment(changeJobCompartmentRequest: requests.ChangeJobCompartmentRequest): Promise<responses.ChangeJobCompartmentResponse>;
    /**
     * Moves a Managed Database Group to a different compartment.
     * The destination compartment must not have a Managed Database Group
     * with the same name.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeManagedDatabaseGroupCompartmentRequest
     * @return ChangeManagedDatabaseGroupCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ChangeManagedDatabaseGroupCompartment.ts.html |here} to see how to use ChangeManagedDatabaseGroupCompartment API.
     */
    changeManagedDatabaseGroupCompartment(changeManagedDatabaseGroupCompartmentRequest: requests.ChangeManagedDatabaseGroupCompartmentRequest): Promise<responses.ChangeManagedDatabaseGroupCompartmentResponse>;
    /**
     * Creates a new Database Management private endpoint.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDbManagementPrivateEndpointRequest
     * @return CreateDbManagementPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/CreateDbManagementPrivateEndpoint.ts.html |here} to see how to use CreateDbManagementPrivateEndpoint API.
     */
    createDbManagementPrivateEndpoint(createDbManagementPrivateEndpointRequest: requests.CreateDbManagementPrivateEndpointRequest): Promise<responses.CreateDbManagementPrivateEndpointResponse>;
    /**
     * Creates a job to be executed on a Managed Database or Managed Database Group. Only one
     * of the parameters, managedDatabaseId or managedDatabaseGroupId should be provided as
     * input in CreateJobDetails resource in request body.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateJobRequest
     * @return CreateJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/CreateJob.ts.html |here} to see how to use CreateJob API.
     */
    createJob(createJobRequest: requests.CreateJobRequest): Promise<responses.CreateJobResponse>;
    /**
     * Creates a Managed Database Group. The group does not contain any
     * Managed Databases when it is created, and they must be added later.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateManagedDatabaseGroupRequest
     * @return CreateManagedDatabaseGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/CreateManagedDatabaseGroup.ts.html |here} to see how to use CreateManagedDatabaseGroup API.
     */
    createManagedDatabaseGroup(createManagedDatabaseGroupRequest: requests.CreateManagedDatabaseGroupRequest): Promise<responses.CreateManagedDatabaseGroupResponse>;
    /**
     * Deletes a specific Database Management private endpoint.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDbManagementPrivateEndpointRequest
     * @return DeleteDbManagementPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/DeleteDbManagementPrivateEndpoint.ts.html |here} to see how to use DeleteDbManagementPrivateEndpoint API.
     */
    deleteDbManagementPrivateEndpoint(deleteDbManagementPrivateEndpointRequest: requests.DeleteDbManagementPrivateEndpointRequest): Promise<responses.DeleteDbManagementPrivateEndpointResponse>;
    /**
     * Deletes the job specified by jobId.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteJobRequest
     * @return DeleteJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/DeleteJob.ts.html |here} to see how to use DeleteJob API.
     */
    deleteJob(deleteJobRequest: requests.DeleteJobRequest): Promise<responses.DeleteJobResponse>;
    /**
     * Deletes the Managed Database Group specified by managedDatabaseGroupId.
     * If the group contains Managed Databases, then it cannot be deleted.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteManagedDatabaseGroupRequest
     * @return DeleteManagedDatabaseGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/DeleteManagedDatabaseGroup.ts.html |here} to see how to use DeleteManagedDatabaseGroup API.
     */
    deleteManagedDatabaseGroup(deleteManagedDatabaseGroupRequest: requests.DeleteManagedDatabaseGroupRequest): Promise<responses.DeleteManagedDatabaseGroupResponse>;
    /**
     * Gets the AWR report for the specific database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAwrDbReportRequest
     * @return GetAwrDbReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetAwrDbReport.ts.html |here} to see how to use GetAwrDbReport API.
     */
    getAwrDbReport(getAwrDbReportRequest: requests.GetAwrDbReportRequest): Promise<responses.GetAwrDbReportResponse>;
    /**
     * Gets the SQL health check report for one SQL of the specific database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAwrDbSqlReportRequest
     * @return GetAwrDbSqlReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetAwrDbSqlReport.ts.html |here} to see how to use GetAwrDbSqlReport API.
     */
    getAwrDbSqlReport(getAwrDbSqlReportRequest: requests.GetAwrDbSqlReportRequest): Promise<responses.GetAwrDbSqlReportResponse>;
    /**
     * Gets the metrics related to cluster cache for the Oracle
     * Real Application Clusters (Oracle RAC) database specified
     * by managedDatabaseId.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetClusterCacheMetricRequest
     * @return GetClusterCacheMetricResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetClusterCacheMetric.ts.html |here} to see how to use GetClusterCacheMetric API.
     */
    getClusterCacheMetric(getClusterCacheMetricRequest: requests.GetClusterCacheMetricRequest): Promise<responses.GetClusterCacheMetricResponse>;
    /**
     * Gets the health metrics for a fleet of databases in a compartment or in a Managed Database Group.
     * Either the CompartmentId or the ManagedDatabaseGroupId query parameters must be provided to retrieve the health metrics.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDatabaseFleetHealthMetricsRequest
     * @return GetDatabaseFleetHealthMetricsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetDatabaseFleetHealthMetrics.ts.html |here} to see how to use GetDatabaseFleetHealthMetrics API.
     */
    getDatabaseFleetHealthMetrics(getDatabaseFleetHealthMetricsRequest: requests.GetDatabaseFleetHealthMetricsRequest): Promise<responses.GetDatabaseFleetHealthMetricsResponse>;
    /**
     * Gets a summary of the activity and resource usage metrics like DB Time, CPU, User I/O, Wait, Storage, and Memory for a Managed Database.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDatabaseHomeMetricsRequest
     * @return GetDatabaseHomeMetricsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetDatabaseHomeMetrics.ts.html |here} to see how to use GetDatabaseHomeMetrics API.
     */
    getDatabaseHomeMetrics(getDatabaseHomeMetricsRequest: requests.GetDatabaseHomeMetricsRequest): Promise<responses.GetDatabaseHomeMetricsResponse>;
    /**
     * Gets the details of a specific Database Management private endpoint.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDbManagementPrivateEndpointRequest
     * @return GetDbManagementPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetDbManagementPrivateEndpoint.ts.html |here} to see how to use GetDbManagementPrivateEndpoint API.
     */
    getDbManagementPrivateEndpoint(getDbManagementPrivateEndpointRequest: requests.GetDbManagementPrivateEndpointRequest): Promise<responses.GetDbManagementPrivateEndpointResponse>;
    /**
     * Gets the details for the job specified by jobId.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetJobRequest
     * @return GetJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetJob.ts.html |here} to see how to use GetJob API.
     */
    getJob(getJobRequest: requests.GetJobRequest): Promise<responses.GetJobResponse>;
    /**
     * Gets the details for the job execution specified by jobExecutionId.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetJobExecutionRequest
     * @return GetJobExecutionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetJobExecution.ts.html |here} to see how to use GetJobExecution API.
     */
    getJobExecution(getJobExecutionRequest: requests.GetJobExecutionRequest): Promise<responses.GetJobExecutionResponse>;
    /**
     * Gets the details for the job run specified by jobRunId.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetJobRunRequest
     * @return GetJobRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetJobRun.ts.html |here} to see how to use GetJobRun API.
     */
    getJobRun(getJobRunRequest: requests.GetJobRunRequest): Promise<responses.GetJobRunResponse>;
    /**
     * Gets the details for the Managed Database specified by managedDatabaseId.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetManagedDatabaseRequest
     * @return GetManagedDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetManagedDatabase.ts.html |here} to see how to use GetManagedDatabase API.
     */
    getManagedDatabase(getManagedDatabaseRequest: requests.GetManagedDatabaseRequest): Promise<responses.GetManagedDatabaseResponse>;
    /**
     * Gets the details for the Managed Database Group specified by managedDatabaseGroupId.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetManagedDatabaseGroupRequest
     * @return GetManagedDatabaseGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetManagedDatabaseGroup.ts.html |here} to see how to use GetManagedDatabaseGroup API.
     */
    getManagedDatabaseGroup(getManagedDatabaseGroupRequest: requests.GetManagedDatabaseGroupRequest): Promise<responses.GetManagedDatabaseGroupResponse>;
    /**
     * Gets a summary of the resource usage metrics such as CPU, User I/O, and Storage for each
     * PDB within a specific CDB. If comparmentId is specified, then the metrics for
     * each PDB (within the CDB) in the specified compartment are retrieved.
     * If compartmentId is not specified, then the metrics for all the PDBs within the CDB are retrieved.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetPdbMetricsRequest
     * @return GetPdbMetricsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetPdbMetrics.ts.html |here} to see how to use GetPdbMetrics API.
     */
    getPdbMetrics(getPdbMetricsRequest: requests.GetPdbMetricsRequest): Promise<responses.GetPdbMetricsResponse>;
    /**
     * Gets the details of a specific user for the specified managedDatabaseId and userName.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetUserRequest
     * @return GetUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetUser.ts.html |here} to see how to use GetUser API.
     */
    getUser(getUserRequest: requests.GetUserRequest): Promise<responses.GetUserResponse>;
    /**
     * Gets the status of the work request with the given Work Request ID
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Gets the list of databases using a specific Database Management private endpoint.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAssociatedDatabasesRequest
     * @return ListAssociatedDatabasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListAssociatedDatabases.ts.html |here} to see how to use ListAssociatedDatabases API.
     */
    listAssociatedDatabases(listAssociatedDatabasesRequest: requests.ListAssociatedDatabasesRequest): Promise<responses.ListAssociatedDatabasesResponse>;
    /**
     * Lists AWR snapshots for the specified database in the AWR.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAwrDbSnapshotsRequest
     * @return ListAwrDbSnapshotsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListAwrDbSnapshots.ts.html |here} to see how to use ListAwrDbSnapshots API.
     */
    listAwrDbSnapshots(listAwrDbSnapshotsRequest: requests.ListAwrDbSnapshotsRequest): Promise<responses.ListAwrDbSnapshotsResponse>;
    /**
     * Gets the list of databases and their snapshot summary details available in the AWR of the specified Managed Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAwrDbsRequest
     * @return ListAwrDbsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListAwrDbs.ts.html |here} to see how to use ListAwrDbs API.
     */
    listAwrDbs(listAwrDbsRequest: requests.ListAwrDbsRequest): Promise<responses.ListAwrDbsResponse>;
    /**
     * Gets the list of Consumer Group Privileges granted for the specified user.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListConsumerGroupPrivilegesRequest
     * @return ListConsumerGroupPrivilegesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListConsumerGroupPrivileges.ts.html |here} to see how to use ListConsumerGroupPrivileges API.
     */
    listConsumerGroupPrivileges(listConsumerGroupPrivilegesRequest: requests.ListConsumerGroupPrivilegesRequest): Promise<responses.ListConsumerGroupPrivilegesResponse>;
    /**
     * Gets the list of Containers if it does not apply to all containers for the specified user.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDataAccessContainersRequest
     * @return ListDataAccessContainersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListDataAccessContainers.ts.html |here} to see how to use ListDataAccessContainers API.
     */
    listDataAccessContainers(listDataAccessContainersRequest: requests.ListDataAccessContainersRequest): Promise<responses.ListDataAccessContainersResponse>;
    /**
     * Gets the list of database parameters for the specified Managed Database. The parameters are listed in alphabetical order, along with their current values.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDatabaseParametersRequest
     * @return ListDatabaseParametersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListDatabaseParameters.ts.html |here} to see how to use ListDatabaseParameters API.
     */
    listDatabaseParameters(listDatabaseParametersRequest: requests.ListDatabaseParametersRequest): Promise<responses.ListDatabaseParametersResponse>;
    /**
     * Gets a list of Database Management private endpoints.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDbManagementPrivateEndpointsRequest
     * @return ListDbManagementPrivateEndpointsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListDbManagementPrivateEndpoints.ts.html |here} to see how to use ListDbManagementPrivateEndpoints API.
     */
    listDbManagementPrivateEndpoints(listDbManagementPrivateEndpointsRequest: requests.ListDbManagementPrivateEndpointsRequest): Promise<responses.ListDbManagementPrivateEndpointsResponse>;
    /**
     * Gets the job execution for a specific ID or the list of job executions for a job, job run, Managed Database or Managed Database Group
     * in a specific compartment. Only one of the parameters, ID, jobId, jobRunId, managedDatabaseId or managedDatabaseGroupId should be provided.
     * If none of these parameters is provided, all the job executions in the compartment are listed. Job executions can also be filtered
     * based on the name and status parameters.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListJobExecutionsRequest
     * @return ListJobExecutionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListJobExecutions.ts.html |here} to see how to use ListJobExecutions API.
     */
    listJobExecutions(listJobExecutionsRequest: requests.ListJobExecutionsRequest): Promise<responses.ListJobExecutionsResponse>;
    /**
     * Gets the job run for a specific ID or the list of job runs for a job, Managed Database or Managed Database Group
     * in a specific compartment. Only one of the parameters, ID, jobId, managedDatabaseId, or managedDatabaseGroupId
     * should be provided. If none of these parameters is provided, all the job runs in the compartment are listed.
     * Job runs can also be filtered based on name and runStatus parameters.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListJobRunsRequest
     * @return ListJobRunsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListJobRuns.ts.html |here} to see how to use ListJobRuns API.
     */
    listJobRuns(listJobRunsRequest: requests.ListJobRunsRequest): Promise<responses.ListJobRunsResponse>;
    /**
     * Gets the job for a specific ID or the list of jobs for a Managed Database or Managed Database Group
     * in a specific compartment. Only one of the parameters, ID, managedDatabaseId or managedDatabaseGroupId,
     * should be provided. If none of these parameters is provided, all the jobs in the compartment are listed.
     * Jobs can also be filtered based on the name and lifecycleState parameters.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListJobsRequest
     * @return ListJobsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListJobs.ts.html |here} to see how to use ListJobs API.
     */
    listJobs(listJobsRequest: requests.ListJobsRequest): Promise<responses.ListJobsResponse>;
    /**
     * Gets the Managed Database Group for a specific ID or the list of Managed Database Groups in
     * a specific compartment. Managed Database Groups can also be filtered based on the name parameter.
     * Only one of the parameters, ID or name should be provided. If none of these parameters is provided,
     * all the Managed Database Groups in the compartment are listed.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListManagedDatabaseGroupsRequest
     * @return ListManagedDatabaseGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListManagedDatabaseGroups.ts.html |here} to see how to use ListManagedDatabaseGroups API.
     */
    listManagedDatabaseGroups(listManagedDatabaseGroupsRequest: requests.ListManagedDatabaseGroupsRequest): Promise<responses.ListManagedDatabaseGroupsResponse>;
    /**
     * Gets the Managed Database for a specific ID or the list of Managed Databases in a specific compartment.
     * Managed Databases can be filtered based on the name parameter. Only one of the parameters, ID or name
     * should be provided. If neither of these parameters is provided, all the Managed Databases in the compartment
     * are listed. Managed Databases can also be filtered based on the deployment type and management option.
     * If the deployment type is not specified or if it is `ONPREMISE`, then the management option is not
     * considered and Managed Databases with `ADVANCED` management option are listed.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListManagedDatabasesRequest
     * @return ListManagedDatabasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListManagedDatabases.ts.html |here} to see how to use ListManagedDatabases API.
     */
    listManagedDatabases(listManagedDatabasesRequest: requests.ListManagedDatabasesRequest): Promise<responses.ListManagedDatabasesResponse>;
    /**
     * Gets the list of Object Privileges granted for the specified user.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListObjectPrivilegesRequest
     * @return ListObjectPrivilegesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListObjectPrivileges.ts.html |here} to see how to use ListObjectPrivileges API.
     */
    listObjectPrivileges(listObjectPrivilegesRequest: requests.ListObjectPrivilegesRequest): Promise<responses.ListObjectPrivilegesResponse>;
    /**
     * Gets the list of Users for which the current user acts as proxy.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListProxiedForUsersRequest
     * @return ListProxiedForUsersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListProxiedForUsers.ts.html |here} to see how to use ListProxiedForUsers API.
     */
    listProxiedForUsers(listProxiedForUsersRequest: requests.ListProxiedForUsersRequest): Promise<responses.ListProxiedForUsersResponse>;
    /**
     * Gets the list of proxy users for the current User.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListProxyUsersRequest
     * @return ListProxyUsersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListProxyUsers.ts.html |here} to see how to use ListProxyUsers API.
     */
    listProxyUsers(listProxyUsersRequest: requests.ListProxyUsersRequest): Promise<responses.ListProxyUsersResponse>;
    /**
     * Gets the list of roles granted for the specified user.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListRolesRequest
     * @return ListRolesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListRoles.ts.html |here} to see how to use ListRoles API.
     */
    listRoles(listRolesRequest: requests.ListRolesRequest): Promise<responses.ListRolesResponse>;
    /**
     * Gets the list of System Privileges granted for the specified user.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSystemPrivilegesRequest
     * @return ListSystemPrivilegesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListSystemPrivileges.ts.html |here} to see how to use ListSystemPrivileges API.
     */
    listSystemPrivileges(listSystemPrivilegesRequest: requests.ListSystemPrivilegesRequest): Promise<responses.ListSystemPrivilegesResponse>;
    /**
     * Gets the list of tablespaces for the specified managedDatabaseId.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListTablespacesRequest
     * @return ListTablespacesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListTablespaces.ts.html |here} to see how to use ListTablespaces API.
     */
    listTablespaces(listTablespacesRequest: requests.ListTablespacesRequest): Promise<responses.ListTablespacesResponse>;
    /**
     * Gets the list of users for the specified managedDatabaseId.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListUsersRequest
     * @return ListUsersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListUsers.ts.html |here} to see how to use ListUsers API.
     */
    listUsers(listUsersRequest: requests.ListUsersRequest): Promise<responses.ListUsersResponse>;
    /**
     * Returns a paginated list of errors for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Returns a paginated list of logs for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * The list of work requests in a specific compartment was retrieved successfully.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Removes a Managed Database from a Managed Database Group. Any management
     * activities that are currently running on this database will continue to
     * run to completion. However, any activities scheduled to run in the future
     * will not be performed on this database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveManagedDatabaseFromManagedDatabaseGroupRequest
     * @return RemoveManagedDatabaseFromManagedDatabaseGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/RemoveManagedDatabaseFromManagedDatabaseGroup.ts.html |here} to see how to use RemoveManagedDatabaseFromManagedDatabaseGroup API.
     */
    removeManagedDatabaseFromManagedDatabaseGroup(removeManagedDatabaseFromManagedDatabaseGroupRequest: requests.RemoveManagedDatabaseFromManagedDatabaseGroupRequest): Promise<responses.RemoveManagedDatabaseFromManagedDatabaseGroupResponse>;
    /**
     * Resets database parameter values to their default or startup values.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ResetDatabaseParametersRequest
     * @return ResetDatabaseParametersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ResetDatabaseParameters.ts.html |here} to see how to use ResetDatabaseParameters API.
     */
    resetDatabaseParameters(resetDatabaseParametersRequest: requests.ResetDatabaseParametersRequest): Promise<responses.ResetDatabaseParametersResponse>;
    /**
     * Summarizes the AWR CPU resource limits and metrics for the specified database in AWR.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeAwrDbCpuUsagesRequest
     * @return SummarizeAwrDbCpuUsagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/SummarizeAwrDbCpuUsages.ts.html |here} to see how to use SummarizeAwrDbCpuUsages API.
     */
    summarizeAwrDbCpuUsages(summarizeAwrDbCpuUsagesRequest: requests.SummarizeAwrDbCpuUsagesRequest): Promise<responses.SummarizeAwrDbCpuUsagesResponse>;
    /**
     * Summarizes the metric samples for the specified database in the AWR. The metric samples are summarized based on the Time dimension for each metric.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeAwrDbMetricsRequest
     * @return SummarizeAwrDbMetricsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/SummarizeAwrDbMetrics.ts.html |here} to see how to use SummarizeAwrDbMetrics API.
     */
    summarizeAwrDbMetrics(summarizeAwrDbMetricsRequest: requests.SummarizeAwrDbMetricsRequest): Promise<responses.SummarizeAwrDbMetricsResponse>;
    /**
     * Summarizes the database parameter change history for one database parameter of the specified database in AWR. One change history record contains
     * the previous value, the changed value, and the corresponding time range. If the database parameter value was changed multiple times within the time range, then multiple change history records are created for the same parameter.
     * Note that this API only returns information on change history details for one database parameter.
     * To get a list of all the database parameters whose values were changed during a specified time range, use the following API endpoint:
     * /managedDatabases/{managedDatabaseId}/awrDbs/{awrDbId}/awrDbParameters
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeAwrDbParameterChangesRequest
     * @return SummarizeAwrDbParameterChangesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/SummarizeAwrDbParameterChanges.ts.html |here} to see how to use SummarizeAwrDbParameterChanges API.
     */
    summarizeAwrDbParameterChanges(summarizeAwrDbParameterChangesRequest: requests.SummarizeAwrDbParameterChangesRequest): Promise<responses.SummarizeAwrDbParameterChangesResponse>;
    /**
       * Summarizes the database parameter history for the specified database in AWR. This includes the list of database
  * parameters, with information on whether the parameter values were modified within the query time range. Note that
  * each database parameter is only listed once. Depending on the optional query parameters, the returned summary gets all the database parameters, which include:
  * <p>
  - Each parameter whose value was changed during the time range:  (valueChanged =\"Y\")
  * - Each parameter whose value was unchanged during the time range:  (valueChanged =\"N\")
  * - Each parameter whose value was changed at the system level during the time range: (valueChanged =\"Y\"  and valueModified = \"SYSTEM_MOD\")
  * - Each parameter whose value was unchanged during the time range, however, the value is not the default value: (valueChanged =\"N\" and  valueDefault = \"FALSE\")
  * <p>
  Note that this API does not return information on the number of times each database parameter has been changed within the time range. To get the database parameter value change history for a specific parameter, use the following API endpoint:
  * /managedDatabases/{managedDatabaseId}/awrDbs/{awrDbId}/awrDbParameterChanges
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param SummarizeAwrDbParametersRequest
       * @return SummarizeAwrDbParametersResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/SummarizeAwrDbParameters.ts.html |here} to see how to use SummarizeAwrDbParameters API.
       */
    summarizeAwrDbParameters(summarizeAwrDbParametersRequest: requests.SummarizeAwrDbParametersRequest): Promise<responses.SummarizeAwrDbParametersResponse>;
    /**
     * Summarizes the AWR snapshot ranges that contain continuous snapshots, for the specified Managed Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeAwrDbSnapshotRangesRequest
     * @return SummarizeAwrDbSnapshotRangesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/SummarizeAwrDbSnapshotRanges.ts.html |here} to see how to use SummarizeAwrDbSnapshotRanges API.
     */
    summarizeAwrDbSnapshotRanges(summarizeAwrDbSnapshotRangesRequest: requests.SummarizeAwrDbSnapshotRangesRequest): Promise<responses.SummarizeAwrDbSnapshotRangesResponse>;
    /**
     * Summarizes the AWR SYSSTAT sample data for the specified database in AWR. The statistical data is summarized based on the Time dimension for each statistic.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeAwrDbSysstatsRequest
     * @return SummarizeAwrDbSysstatsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/SummarizeAwrDbSysstats.ts.html |here} to see how to use SummarizeAwrDbSysstats API.
     */
    summarizeAwrDbSysstats(summarizeAwrDbSysstatsRequest: requests.SummarizeAwrDbSysstatsRequest): Promise<responses.SummarizeAwrDbSysstatsResponse>;
    /**
     * Summarizes the AWR top wait events.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeAwrDbTopWaitEventsRequest
     * @return SummarizeAwrDbTopWaitEventsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/SummarizeAwrDbTopWaitEvents.ts.html |here} to see how to use SummarizeAwrDbTopWaitEvents API.
     */
    summarizeAwrDbTopWaitEvents(summarizeAwrDbTopWaitEventsRequest: requests.SummarizeAwrDbTopWaitEventsRequest): Promise<responses.SummarizeAwrDbTopWaitEventsResponse>;
    /**
     * Summarizes AWR wait event data into value buckets and frequency, for the specified database in the AWR.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeAwrDbWaitEventBucketsRequest
     * @return SummarizeAwrDbWaitEventBucketsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/SummarizeAwrDbWaitEventBuckets.ts.html |here} to see how to use SummarizeAwrDbWaitEventBuckets API.
     */
    summarizeAwrDbWaitEventBuckets(summarizeAwrDbWaitEventBucketsRequest: requests.SummarizeAwrDbWaitEventBucketsRequest): Promise<responses.SummarizeAwrDbWaitEventBucketsResponse>;
    /**
     * Summarizes the AWR wait event sample data for the specified database in the AWR. The event data is summarized based on the Time dimension for each event.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeAwrDbWaitEventsRequest
     * @return SummarizeAwrDbWaitEventsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/SummarizeAwrDbWaitEvents.ts.html |here} to see how to use SummarizeAwrDbWaitEvents API.
     */
    summarizeAwrDbWaitEvents(summarizeAwrDbWaitEventsRequest: requests.SummarizeAwrDbWaitEventsRequest): Promise<responses.SummarizeAwrDbWaitEventsResponse>;
    /**
     * Gets the number of job executions grouped by status for a job, Managed Database, or Database Group in a specific compartment. Only one of the parameters, jobId, managedDatabaseId, or managedDatabaseGroupId should be provided.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeJobExecutionsStatusesRequest
     * @return SummarizeJobExecutionsStatusesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/SummarizeJobExecutionsStatuses.ts.html |here} to see how to use SummarizeJobExecutionsStatuses API.
     */
    summarizeJobExecutionsStatuses(summarizeJobExecutionsStatusesRequest: requests.SummarizeJobExecutionsStatusesRequest): Promise<responses.SummarizeJobExecutionsStatusesResponse>;
    /**
     * Updates one or more attributes of a specific Database Management private endpoint.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDbManagementPrivateEndpointRequest
     * @return UpdateDbManagementPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/UpdateDbManagementPrivateEndpoint.ts.html |here} to see how to use UpdateDbManagementPrivateEndpoint API.
     */
    updateDbManagementPrivateEndpoint(updateDbManagementPrivateEndpointRequest: requests.UpdateDbManagementPrivateEndpointRequest): Promise<responses.UpdateDbManagementPrivateEndpointResponse>;
    /**
     * Updates the details for the recurring scheduled job specified by jobId. Note that non-recurring (one time) jobs cannot be updated.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateJobRequest
     * @return UpdateJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/UpdateJob.ts.html |here} to see how to use UpdateJob API.
     */
    updateJob(updateJobRequest: requests.UpdateJobRequest): Promise<responses.UpdateJobResponse>;
    /**
     * Updates the Managed Database Group specified by managedDatabaseGroupId.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateManagedDatabaseGroupRequest
     * @return UpdateManagedDatabaseGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/UpdateManagedDatabaseGroup.ts.html |here} to see how to use UpdateManagedDatabaseGroup API.
     */
    updateManagedDatabaseGroup(updateManagedDatabaseGroupRequest: requests.UpdateManagedDatabaseGroupRequest): Promise<responses.UpdateManagedDatabaseGroupResponse>;
}
export declare enum SqlTuningApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class SqlTuningClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Clone and start a SQL tuning task for a given SQL tuning task.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CloneSqlTuningTaskRequest
     * @return CloneSqlTuningTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/CloneSqlTuningTask.ts.html |here} to see how to use CloneSqlTuningTask API.
     */
    cloneSqlTuningTask(cloneSqlTuningTaskRequest: requests.CloneSqlTuningTaskRequest): Promise<responses.CloneSqlTuningTaskResponse>;
    /**
     * Drop a SQL tuning task and its related results from the database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DropSqlTuningTaskRequest
     * @return DropSqlTuningTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/DropSqlTuningTask.ts.html |here} to see how to use DropSqlTuningTask API.
     */
    dropSqlTuningTask(dropSqlTuningTaskRequest: requests.DropSqlTuningTaskRequest): Promise<responses.DropSqlTuningTaskResponse>;
    /**
     * A SQL tuning task may suggest new execution plan for a SQL. The API returns the
     * stats comparison report for the plans.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExecutionPlanStatsComparisionRequest
     * @return GetExecutionPlanStatsComparisionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetExecutionPlanStatsComparision.ts.html |here} to see how to use GetExecutionPlanStatsComparision API.
     */
    getExecutionPlanStatsComparision(getExecutionPlanStatsComparisionRequest: requests.GetExecutionPlanStatsComparisionRequest): Promise<responses.GetExecutionPlanStatsComparisionResponse>;
    /**
     * Retrieve a SQL execution plan for a SQL being tuned, for original or new plan
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetSqlExecutionPlanRequest
     * @return GetSqlExecutionPlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetSqlExecutionPlan.ts.html |here} to see how to use GetSqlExecutionPlan API.
     */
    getSqlExecutionPlan(getSqlExecutionPlanRequest: requests.GetSqlExecutionPlanRequest): Promise<responses.GetSqlExecutionPlanResponse>;
    /**
     * Gets the summary report for the specific SQL Tuning Advisor task.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetSqlTuningAdvisorTaskSummaryReportRequest
     * @return GetSqlTuningAdvisorTaskSummaryReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/GetSqlTuningAdvisorTaskSummaryReport.ts.html |here} to see how to use GetSqlTuningAdvisorTaskSummaryReport API.
     */
    getSqlTuningAdvisorTaskSummaryReport(getSqlTuningAdvisorTaskSummaryReportRequest: requests.GetSqlTuningAdvisorTaskSummaryReportRequest): Promise<responses.GetSqlTuningAdvisorTaskSummaryReportResponse>;
    /**
     * Takes in a task id, and a finding/object type filter and applies some SQLs to find return the output.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSqlTuningAdvisorTaskFindingsRequest
     * @return ListSqlTuningAdvisorTaskFindingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListSqlTuningAdvisorTaskFindings.ts.html |here} to see how to use ListSqlTuningAdvisorTaskFindings API.
     */
    listSqlTuningAdvisorTaskFindings(listSqlTuningAdvisorTaskFindingsRequest: requests.ListSqlTuningAdvisorTaskFindingsRequest): Promise<responses.ListSqlTuningAdvisorTaskFindingsResponse>;
    /**
     * Takes in a task id and object id and returns the recommendations/findings.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSqlTuningAdvisorTaskRecommendationsRequest
     * @return ListSqlTuningAdvisorTaskRecommendationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListSqlTuningAdvisorTaskRecommendations.ts.html |here} to see how to use ListSqlTuningAdvisorTaskRecommendations API.
     */
    listSqlTuningAdvisorTaskRecommendations(listSqlTuningAdvisorTaskRecommendationsRequest: requests.ListSqlTuningAdvisorTaskRecommendationsRequest): Promise<responses.ListSqlTuningAdvisorTaskRecommendationsResponse>;
    /**
     * Lists the SQL Tuning Advisor tasks for the specified Managed Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSqlTuningAdvisorTasksRequest
     * @return ListSqlTuningAdvisorTasksResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/ListSqlTuningAdvisorTasks.ts.html |here} to see how to use ListSqlTuningAdvisorTasks API.
     */
    listSqlTuningAdvisorTasks(listSqlTuningAdvisorTasksRequest: requests.ListSqlTuningAdvisorTasksRequest): Promise<responses.ListSqlTuningAdvisorTasksResponse>;
    /**
     * Start a SQL tuning task for a given set of SQLs from active session history
     * top SQLs.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param StartSqlTuningTaskRequest
     * @return StartSqlTuningTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/databasemanagement/StartSqlTuningTask.ts.html |here} to see how to use StartSqlTuningTask API.
     */
    startSqlTuningTask(startSqlTuningTaskRequest: requests.StartSqlTuningTaskRequest): Promise<responses.StartSqlTuningTaskResponse>;
}
