/**
 * Data Safe API
 * APIs for using Oracle Data Safe.
 * OpenAPI spec version: 20181201
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as model from "./model";
import * as responses from "./response";
import { DataSafeWaiter } from "./datasafe-waiter";
export declare enum DataSafeApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class DataSafeClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DataSafeWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DataSafeWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DataSafeWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DataSafeWaiter;
    /**
     * Reactivates a previously deactivated Data Safe target database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ActivateTargetDatabaseRequest
     * @return ActivateTargetDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ActivateTargetDatabase.ts.html |here} to see how to use ActivateTargetDatabase API.
     */
    activateTargetDatabase(activateTargetDatabaseRequest: requests.ActivateTargetDatabaseRequest): Promise<responses.ActivateTargetDatabaseResponse>;
    /**
     * Moves the Data Safe private endpoint and its dependent resources to the specified compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeDataSafePrivateEndpointCompartmentRequest
     * @return ChangeDataSafePrivateEndpointCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ChangeDataSafePrivateEndpointCompartment.ts.html |here} to see how to use ChangeDataSafePrivateEndpointCompartment API.
     */
    changeDataSafePrivateEndpointCompartment(changeDataSafePrivateEndpointCompartmentRequest: requests.ChangeDataSafePrivateEndpointCompartmentRequest): Promise<responses.ChangeDataSafePrivateEndpointCompartmentResponse>;
    /**
     * Moves the specified on-premises connector into a different compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeOnPremConnectorCompartmentRequest
     * @return ChangeOnPremConnectorCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ChangeOnPremConnectorCompartment.ts.html |here} to see how to use ChangeOnPremConnectorCompartment API.
     */
    changeOnPremConnectorCompartment(changeOnPremConnectorCompartmentRequest: requests.ChangeOnPremConnectorCompartmentRequest): Promise<responses.ChangeOnPremConnectorCompartmentResponse>;
    /**
       * Moves the specified saved security assessment or future scheduled assessments into a different compartment.
  * <p>
  To start, call first the operation ListSecurityAssessments with filters \"type = save_schedule\". This returns the scheduleAssessmentId. Then, call this changeCompartment with the scheduleAssessmentId.
  * <p>
  The existing saved security assessments created due to the schedule are not moved. However, all new saves will be associated with the new compartment.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ChangeSecurityAssessmentCompartmentRequest
       * @return ChangeSecurityAssessmentCompartmentResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ChangeSecurityAssessmentCompartment.ts.html |here} to see how to use ChangeSecurityAssessmentCompartment API.
       */
    changeSecurityAssessmentCompartment(changeSecurityAssessmentCompartmentRequest: requests.ChangeSecurityAssessmentCompartmentRequest): Promise<responses.ChangeSecurityAssessmentCompartmentResponse>;
    /**
     * Moves the Data Safe target database to the specified compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeTargetDatabaseCompartmentRequest
     * @return ChangeTargetDatabaseCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ChangeTargetDatabaseCompartment.ts.html |here} to see how to use ChangeTargetDatabaseCompartment API.
     */
    changeTargetDatabaseCompartment(changeTargetDatabaseCompartmentRequest: requests.ChangeTargetDatabaseCompartmentRequest): Promise<responses.ChangeTargetDatabaseCompartmentResponse>;
    /**
     * Moves the specified saved user assessment or future scheduled assessments into a different compartment.
     * To start storing scheduled user assessments on a different compartment, first call the operation ListUserAssessments with
     * the filters \"type = save_schedule\". That call returns the scheduleAssessmentId. Then call
     * ChangeUserAssessmentCompartment with the scheduleAssessmentId. The existing saved user assessments created per the schedule
     * are not be moved. However, all new saves will be associated with the new compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeUserAssessmentCompartmentRequest
     * @return ChangeUserAssessmentCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ChangeUserAssessmentCompartment.ts.html |here} to see how to use ChangeUserAssessmentCompartment API.
     */
    changeUserAssessmentCompartment(changeUserAssessmentCompartmentRequest: requests.ChangeUserAssessmentCompartmentRequest): Promise<responses.ChangeUserAssessmentCompartmentResponse>;
    /**
     * Compares two security assessments. For this comparison, a security assessment can be a saved assessment, a latest assessment, or a baseline assessment.
     * For example, you can compare saved assessment or a latest assessment against a baseline.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CompareSecurityAssessmentRequest
     * @return CompareSecurityAssessmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/CompareSecurityAssessment.ts.html |here} to see how to use CompareSecurityAssessment API.
     */
    compareSecurityAssessment(compareSecurityAssessmentRequest: requests.CompareSecurityAssessmentRequest): Promise<responses.CompareSecurityAssessmentResponse>;
    /**
     * Compares two user assessments. For this comparison, a user assessment can be a saved, a latest assessment, or a baseline.
     * As an example, it can be used to compare a user assessment saved or a latest assessment with a baseline.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CompareUserAssessmentRequest
     * @return CompareUserAssessmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/CompareUserAssessment.ts.html |here} to see how to use CompareUserAssessment API.
     */
    compareUserAssessment(compareUserAssessmentRequest: requests.CompareUserAssessmentRequest): Promise<responses.CompareUserAssessmentResponse>;
    /**
     * Creates a new Data Safe private endpoint.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDataSafePrivateEndpointRequest
     * @return CreateDataSafePrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/CreateDataSafePrivateEndpoint.ts.html |here} to see how to use CreateDataSafePrivateEndpoint API.
     */
    createDataSafePrivateEndpoint(createDataSafePrivateEndpointRequest: requests.CreateDataSafePrivateEndpointRequest): Promise<responses.CreateDataSafePrivateEndpointResponse>;
    /**
     * Creates a new on-premises connector.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateOnPremConnectorRequest
     * @return CreateOnPremConnectorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/CreateOnPremConnector.ts.html |here} to see how to use CreateOnPremConnector API.
     */
    createOnPremConnector(createOnPremConnectorRequest: requests.CreateOnPremConnectorRequest): Promise<responses.CreateOnPremConnectorResponse>;
    /**
     * Creates a new saved security assessment for one or multiple targets in a compartment. When this operation is performed,
     * it will save the latest assessments in the specified compartment. If a schedule is passed, it will persist the latest assessments,
     * at the defined date and time, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateSecurityAssessmentRequest
     * @return CreateSecurityAssessmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/CreateSecurityAssessment.ts.html |here} to see how to use CreateSecurityAssessment API.
     */
    createSecurityAssessment(createSecurityAssessmentRequest: requests.CreateSecurityAssessmentRequest): Promise<responses.CreateSecurityAssessmentResponse>;
    /**
     * Registers the specified database with Data Safe and creates a Data Safe target database in the Data Safe Console.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateTargetDatabaseRequest
     * @return CreateTargetDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/CreateTargetDatabase.ts.html |here} to see how to use CreateTargetDatabase API.
     */
    createTargetDatabase(createTargetDatabaseRequest: requests.CreateTargetDatabaseRequest): Promise<responses.CreateTargetDatabaseResponse>;
    /**
     * Creates a new saved user assessment for one or multiple targets in a compartment. It saves the latest assessments in the
     * specified compartment. If a scheduled is passed in, this operation persists the latest assessments that exist at the defined
     * date and time, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateUserAssessmentRequest
     * @return CreateUserAssessmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/CreateUserAssessment.ts.html |here} to see how to use CreateUserAssessment API.
     */
    createUserAssessment(createUserAssessmentRequest: requests.CreateUserAssessmentRequest): Promise<responses.CreateUserAssessmentResponse>;
    /**
     * Deactivates a target database in Data Safe.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeactivateTargetDatabaseRequest
     * @return DeactivateTargetDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/DeactivateTargetDatabase.ts.html |here} to see how to use DeactivateTargetDatabase API.
     */
    deactivateTargetDatabase(deactivateTargetDatabaseRequest: requests.DeactivateTargetDatabaseRequest): Promise<responses.DeactivateTargetDatabaseResponse>;
    /**
     * Deletes the specified Data Safe private endpoint.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDataSafePrivateEndpointRequest
     * @return DeleteDataSafePrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/DeleteDataSafePrivateEndpoint.ts.html |here} to see how to use DeleteDataSafePrivateEndpoint API.
     */
    deleteDataSafePrivateEndpoint(deleteDataSafePrivateEndpointRequest: requests.DeleteDataSafePrivateEndpointRequest): Promise<responses.DeleteDataSafePrivateEndpointResponse>;
    /**
     * Deletes the specified on-premises connector.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteOnPremConnectorRequest
     * @return DeleteOnPremConnectorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/DeleteOnPremConnector.ts.html |here} to see how to use DeleteOnPremConnector API.
     */
    deleteOnPremConnector(deleteOnPremConnectorRequest: requests.DeleteOnPremConnectorRequest): Promise<responses.DeleteOnPremConnectorResponse>;
    /**
     * Deletes the specified saved security assessment or schedule. To delete a security assessment schedule,
     * first call the operation ListSecurityAssessments with filters \"type = save_schedule\".
     * That operation returns the scheduleAssessmentId. Then, call DeleteSecurityAssessment with the scheduleAssessmentId.
     * If the assessment being deleted is the baseline for that compartment, then it will impact all baselines in the compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteSecurityAssessmentRequest
     * @return DeleteSecurityAssessmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/DeleteSecurityAssessment.ts.html |here} to see how to use DeleteSecurityAssessment API.
     */
    deleteSecurityAssessment(deleteSecurityAssessmentRequest: requests.DeleteSecurityAssessmentRequest): Promise<responses.DeleteSecurityAssessmentResponse>;
    /**
     * Deregisters the specified database from Data Safe and removes the target database from the Data Safe Console.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteTargetDatabaseRequest
     * @return DeleteTargetDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/DeleteTargetDatabase.ts.html |here} to see how to use DeleteTargetDatabase API.
     */
    deleteTargetDatabase(deleteTargetDatabaseRequest: requests.DeleteTargetDatabaseRequest): Promise<responses.DeleteTargetDatabaseResponse>;
    /**
     * Deletes the specified saved user assessment or schedule. To delete a user assessment schedule, first call the operation
     * ListUserAssessments with filters \"type = save_schedule\".
     * That call returns the scheduleAssessmentId. Then call DeleteUserAssessment with the scheduleAssessmentId.
     * If the assessment being deleted is the baseline for that compartment, then it will impact all baselines in the compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteUserAssessmentRequest
     * @return DeleteUserAssessmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/DeleteUserAssessment.ts.html |here} to see how to use DeleteUserAssessment API.
     */
    deleteUserAssessment(deleteUserAssessmentRequest: requests.DeleteUserAssessmentRequest): Promise<responses.DeleteUserAssessmentResponse>;
    /**
     * Downloads the privilege script to grant/revoke required roles from the Data Safe account on the target database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DownloadPrivilegeScriptRequest
     * @return DownloadPrivilegeScriptResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/DownloadPrivilegeScript.ts.html |here} to see how to use DownloadPrivilegeScript API.
     */
    downloadPrivilegeScript(downloadPrivilegeScriptRequest: requests.DownloadPrivilegeScriptRequest): Promise<responses.DownloadPrivilegeScriptResponse>;
    /**
     * Downloads the report of the specified security assessment. To download the security assessment report, it needs to be generated first.
     * Please use GenerateSecurityAssessmentReport to generate a downloadable report in the preferred format (PDF, XLS).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DownloadSecurityAssessmentReportRequest
     * @return DownloadSecurityAssessmentReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/DownloadSecurityAssessmentReport.ts.html |here} to see how to use DownloadSecurityAssessmentReport API.
     */
    downloadSecurityAssessmentReport(downloadSecurityAssessmentReportRequest: requests.DownloadSecurityAssessmentReportRequest): Promise<responses.DownloadSecurityAssessmentReportResponse>;
    /**
     * Downloads the report of the specified user assessment. To download the user assessment report, it needs to be generated first.
     * Please use GenerateUserAssessmentReport to generate a downloadable report in the preferred format (PDF, XLS).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DownloadUserAssessmentReportRequest
     * @return DownloadUserAssessmentReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/DownloadUserAssessmentReport.ts.html |here} to see how to use DownloadUserAssessmentReport API.
     */
    downloadUserAssessmentReport(downloadUserAssessmentReportRequest: requests.DownloadUserAssessmentReportRequest): Promise<responses.DownloadUserAssessmentReportResponse>;
    /**
     * Enables Data Safe in the tenancy and region.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableDataSafeConfigurationRequest
     * @return EnableDataSafeConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/EnableDataSafeConfiguration.ts.html |here} to see how to use EnableDataSafeConfiguration API.
     */
    enableDataSafeConfiguration(enableDataSafeConfigurationRequest: requests.EnableDataSafeConfigurationRequest): Promise<responses.EnableDataSafeConfigurationResponse>;
    /**
     * Creates and downloads the configuration of the specified on-premises connector.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GenerateOnPremConnectorConfigurationRequest
     * @return GenerateOnPremConnectorConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/GenerateOnPremConnectorConfiguration.ts.html |here} to see how to use GenerateOnPremConnectorConfiguration API.
     */
    generateOnPremConnectorConfiguration(generateOnPremConnectorConfigurationRequest: requests.GenerateOnPremConnectorConfigurationRequest): Promise<responses.GenerateOnPremConnectorConfigurationResponse>;
    /**
     * Generates the report of the specified security assessment. You can get the report in PDF or XLS format.
     * After generating the report, use DownloadSecurityAssessmentReport to download it in the preferred format.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GenerateSecurityAssessmentReportRequest
     * @return GenerateSecurityAssessmentReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/GenerateSecurityAssessmentReport.ts.html |here} to see how to use GenerateSecurityAssessmentReport API.
     */
    generateSecurityAssessmentReport(generateSecurityAssessmentReportRequest: requests.GenerateSecurityAssessmentReportRequest): Promise<responses.GenerateSecurityAssessmentReportResponse>;
    /**
     * Generates the report of the specified user assessment. The report is available in PDF or XLS format.
     * After generating the report, use DownloadUserAssessmentReport to download it in the preferred format.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GenerateUserAssessmentReportRequest
     * @return GenerateUserAssessmentReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/GenerateUserAssessmentReport.ts.html |here} to see how to use GenerateUserAssessmentReport API.
     */
    generateUserAssessmentReport(generateUserAssessmentReportRequest: requests.GenerateUserAssessmentReportRequest): Promise<responses.GenerateUserAssessmentReportResponse>;
    /**
     * Gets the details of the Data Safe configuration.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDataSafeConfigurationRequest
     * @return GetDataSafeConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/GetDataSafeConfiguration.ts.html |here} to see how to use GetDataSafeConfiguration API.
     */
    getDataSafeConfiguration(getDataSafeConfigurationRequest: requests.GetDataSafeConfigurationRequest): Promise<responses.GetDataSafeConfigurationResponse>;
    /**
     * Gets the details of the specified Data Safe private endpoint.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDataSafePrivateEndpointRequest
     * @return GetDataSafePrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/GetDataSafePrivateEndpoint.ts.html |here} to see how to use GetDataSafePrivateEndpoint API.
     */
    getDataSafePrivateEndpoint(getDataSafePrivateEndpointRequest: requests.GetDataSafePrivateEndpointRequest): Promise<responses.GetDataSafePrivateEndpointResponse>;
    /**
     * Gets the details of the specified on-premises connector.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetOnPremConnectorRequest
     * @return GetOnPremConnectorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/GetOnPremConnector.ts.html |here} to see how to use GetOnPremConnector API.
     */
    getOnPremConnector(getOnPremConnectorRequest: requests.GetOnPremConnectorRequest): Promise<responses.GetOnPremConnectorResponse>;
    /**
     * Gets the details of the specified security assessment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetSecurityAssessmentRequest
     * @return GetSecurityAssessmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/GetSecurityAssessment.ts.html |here} to see how to use GetSecurityAssessment API.
     */
    getSecurityAssessment(getSecurityAssessmentRequest: requests.GetSecurityAssessmentRequest): Promise<responses.GetSecurityAssessmentResponse>;
    /**
     * Gets the details of the comparison report on the security assessments submitted for comparison.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetSecurityAssessmentComparisonRequest
     * @return GetSecurityAssessmentComparisonResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/GetSecurityAssessmentComparison.ts.html |here} to see how to use GetSecurityAssessmentComparison API.
     */
    getSecurityAssessmentComparison(getSecurityAssessmentComparisonRequest: requests.GetSecurityAssessmentComparisonRequest): Promise<responses.GetSecurityAssessmentComparisonResponse>;
    /**
     * Returns the details of the specified Data Safe target database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetTargetDatabaseRequest
     * @return GetTargetDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/GetTargetDatabase.ts.html |here} to see how to use GetTargetDatabase API.
     */
    getTargetDatabase(getTargetDatabaseRequest: requests.GetTargetDatabaseRequest): Promise<responses.GetTargetDatabaseResponse>;
    /**
     * Gets a user assessment by identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetUserAssessmentRequest
     * @return GetUserAssessmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/GetUserAssessment.ts.html |here} to see how to use GetUserAssessment API.
     */
    getUserAssessment(getUserAssessmentRequest: requests.GetUserAssessmentRequest): Promise<responses.GetUserAssessmentResponse>;
    /**
     * Gets the details of the comparison report for the user assessments provided.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetUserAssessmentComparisonRequest
     * @return GetUserAssessmentComparisonResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/GetUserAssessmentComparison.ts.html |here} to see how to use GetUserAssessmentComparison API.
     */
    getUserAssessmentComparison(getUserAssessmentComparisonRequest: requests.GetUserAssessmentComparisonRequest): Promise<responses.GetUserAssessmentComparisonResponse>;
    /**
     * Gets the details of the specified work request.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Gets a list of Data Safe private endpoints.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDataSafePrivateEndpointsRequest
     * @return ListDataSafePrivateEndpointsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ListDataSafePrivateEndpoints.ts.html |here} to see how to use ListDataSafePrivateEndpoints API.
     */
    listDataSafePrivateEndpoints(listDataSafePrivateEndpointsRequest: requests.ListDataSafePrivateEndpointsRequest): Promise<responses.ListDataSafePrivateEndpointsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDataSafePrivateEndpointsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DataSafePrivateEndpointSummary objects
     * contained in responses from the listDataSafePrivateEndpoints operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDataSafePrivateEndpoints(request: requests.ListDataSafePrivateEndpointsRequest): AsyncIterableIterator<model.DataSafePrivateEndpointSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDataSafePrivateEndpointsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDataSafePrivateEndpoints operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDataSafePrivateEndpointsResponses(request: requests.ListDataSafePrivateEndpointsRequest): AsyncIterableIterator<responses.ListDataSafePrivateEndpointsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DataSafePrivateEndpointSummary objects
     * contained in responses from the listDataSafePrivateEndpoints operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDataSafePrivateEndpointsRecordIterator(request: requests.ListDataSafePrivateEndpointsRequest): AsyncIterableIterator<model.DataSafePrivateEndpointSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDataSafePrivateEndpoints operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDataSafePrivateEndpointsResponseIterator(request: requests.ListDataSafePrivateEndpointsRequest): AsyncIterableIterator<responses.ListDataSafePrivateEndpointsResponse>;
    /**
     * List all the findings from all the targets in the specified assessment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListFindingsRequest
     * @return ListFindingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ListFindings.ts.html |here} to see how to use ListFindings API.
     */
    listFindings(listFindingsRequest: requests.ListFindingsRequest): Promise<responses.ListFindingsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listFindingsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.FindingSummary objects
     * contained in responses from the listFindings operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllFindings(request: requests.ListFindingsRequest): AsyncIterableIterator<model.FindingSummary>;
    /**
     * NOTE: This function is deprecated in favor of listFindingsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listFindings operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllFindingsResponses(request: requests.ListFindingsRequest): AsyncIterableIterator<responses.ListFindingsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.FindingSummary objects
     * contained in responses from the listFindings operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listFindingsRecordIterator(request: requests.ListFindingsRequest): AsyncIterableIterator<model.FindingSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listFindings operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listFindingsResponseIterator(request: requests.ListFindingsRequest): AsyncIterableIterator<responses.ListFindingsResponse>;
    /**
     * Gets a list of grants for a particular user in the specified user assessment. A user grant contains details such as the
     * privilege name, type, category, and depth level. The depth level indicates how deep in the hierarchy of roles granted to
     * roles a privilege grant is. The userKey in this operation is a system-generated identifier. Perform the operation ListUsers
     * to get the userKey for a particular user.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListGrantsRequest
     * @return ListGrantsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ListGrants.ts.html |here} to see how to use ListGrants API.
     */
    listGrants(listGrantsRequest: requests.ListGrantsRequest): Promise<responses.ListGrantsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listGrantsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.GrantSummary objects
     * contained in responses from the listGrants operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllGrants(request: requests.ListGrantsRequest): AsyncIterableIterator<model.GrantSummary>;
    /**
     * NOTE: This function is deprecated in favor of listGrantsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listGrants operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllGrantsResponses(request: requests.ListGrantsRequest): AsyncIterableIterator<responses.ListGrantsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.GrantSummary objects
     * contained in responses from the listGrants operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listGrantsRecordIterator(request: requests.ListGrantsRequest): AsyncIterableIterator<model.GrantSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listGrants operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listGrantsResponseIterator(request: requests.ListGrantsRequest): AsyncIterableIterator<responses.ListGrantsResponse>;
    /**
     * Gets a list of on-premises connectors.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListOnPremConnectorsRequest
     * @return ListOnPremConnectorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ListOnPremConnectors.ts.html |here} to see how to use ListOnPremConnectors API.
     */
    listOnPremConnectors(listOnPremConnectorsRequest: requests.ListOnPremConnectorsRequest): Promise<responses.ListOnPremConnectorsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listOnPremConnectorsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.OnPremConnectorSummary objects
     * contained in responses from the listOnPremConnectors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllOnPremConnectors(request: requests.ListOnPremConnectorsRequest): AsyncIterableIterator<model.OnPremConnectorSummary>;
    /**
     * NOTE: This function is deprecated in favor of listOnPremConnectorsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listOnPremConnectors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllOnPremConnectorsResponses(request: requests.ListOnPremConnectorsRequest): AsyncIterableIterator<responses.ListOnPremConnectorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.OnPremConnectorSummary objects
     * contained in responses from the listOnPremConnectors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listOnPremConnectorsRecordIterator(request: requests.ListOnPremConnectorsRequest): AsyncIterableIterator<model.OnPremConnectorSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listOnPremConnectors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listOnPremConnectorsResponseIterator(request: requests.ListOnPremConnectorsRequest): AsyncIterableIterator<responses.ListOnPremConnectorsResponse>;
    /**
       * Gets a list of security assessments.
  * <p>
  The ListSecurityAssessments operation returns only the assessments in the specified `compartmentId`.
  * The list does not include any subcompartments of the compartmentId passed.
  * <p>
  The parameter `accessLevel` specifies whether to return only those compartments for which the
  * requestor has INSPECT permissions on at least one resource directly
  * or indirectly (ACCESSIBLE) (the resource can be in a subcompartment) or to return Not Authorized if
  * Principal doesn't have access to even one of the child compartments. This is valid only when
  * `compartmentIdInSubtree` is set to `true`.
  * <p>
  The parameter `compartmentIdInSubtree` applies when you perform ListSecurityAssessments on the
  * `compartmentId` passed and when it is set to true, the entire hierarchy of compartments can be returned.
  * To get a full list of all compartments and subcompartments in the tenancy (root compartment),
  * set the parameter `compartmentIdInSubtree` to true and `accessLevel` to ACCESSIBLE.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ListSecurityAssessmentsRequest
       * @return ListSecurityAssessmentsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ListSecurityAssessments.ts.html |here} to see how to use ListSecurityAssessments API.
       */
    listSecurityAssessments(listSecurityAssessmentsRequest: requests.ListSecurityAssessmentsRequest): Promise<responses.ListSecurityAssessmentsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listSecurityAssessmentsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.SecurityAssessmentSummary objects
     * contained in responses from the listSecurityAssessments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSecurityAssessments(request: requests.ListSecurityAssessmentsRequest): AsyncIterableIterator<model.SecurityAssessmentSummary>;
    /**
     * NOTE: This function is deprecated in favor of listSecurityAssessmentsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listSecurityAssessments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSecurityAssessmentsResponses(request: requests.ListSecurityAssessmentsRequest): AsyncIterableIterator<responses.ListSecurityAssessmentsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.SecurityAssessmentSummary objects
     * contained in responses from the listSecurityAssessments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listSecurityAssessmentsRecordIterator(request: requests.ListSecurityAssessmentsRequest): AsyncIterableIterator<model.SecurityAssessmentSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listSecurityAssessments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listSecurityAssessmentsResponseIterator(request: requests.ListSecurityAssessmentsRequest): AsyncIterableIterator<responses.ListSecurityAssessmentsResponse>;
    /**
     * Returns the list of registered target databases in Data Safe.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListTargetDatabasesRequest
     * @return ListTargetDatabasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ListTargetDatabases.ts.html |here} to see how to use ListTargetDatabases API.
     */
    listTargetDatabases(listTargetDatabasesRequest: requests.ListTargetDatabasesRequest): Promise<responses.ListTargetDatabasesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listTargetDatabasesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.TargetDatabaseSummary objects
     * contained in responses from the listTargetDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllTargetDatabases(request: requests.ListTargetDatabasesRequest): AsyncIterableIterator<model.TargetDatabaseSummary>;
    /**
     * NOTE: This function is deprecated in favor of listTargetDatabasesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listTargetDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllTargetDatabasesResponses(request: requests.ListTargetDatabasesRequest): AsyncIterableIterator<responses.ListTargetDatabasesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.TargetDatabaseSummary objects
     * contained in responses from the listTargetDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listTargetDatabasesRecordIterator(request: requests.ListTargetDatabasesRequest): AsyncIterableIterator<model.TargetDatabaseSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listTargetDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listTargetDatabasesResponseIterator(request: requests.ListTargetDatabasesRequest): AsyncIterableIterator<responses.ListTargetDatabasesResponse>;
    /**
       * Gets a list of aggregated user details from the specified user assessment. This provides information about the overall state
  * of database user security.  For example, the user details include how many users have the DBA role and how many users are in
  * the critical category. This data is especially useful content for dashboards or to support analytics.
  * <p>
  When you perform the ListUserAnalytics operation, if the parameter compartmentIdInSubtree is set to \"true,\" and if the
  * parameter accessLevel is set to ACCESSIBLE, then the operation returns compartments in which the requestor has INSPECT
  * permissions on at least one resource, directly or indirectly (in subcompartments). If the operation is performed at the
  * root compartment. If the requestor does not have access to at least one subcompartment of the compartment specified by
  * compartmentId, then \"Not Authorized\" is returned.
  * <p>
  The parameter compartmentIdInSubtree applies when you perform ListUserAnalytics on the compartmentId passed and when it is
  * set to true, the entire hierarchy of compartments can be returned.
  * <p>
  To use ListUserAnalytics to get a full list of all compartments and subcompartments in the tenancy from the root compartment,
  * set the parameter compartmentIdInSubtree to true and accessLevel to ACCESSIBLE.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ListUserAnalyticsRequest
       * @return ListUserAnalyticsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ListUserAnalytics.ts.html |here} to see how to use ListUserAnalytics API.
       */
    listUserAnalytics(listUserAnalyticsRequest: requests.ListUserAnalyticsRequest): Promise<responses.ListUserAnalyticsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listUserAnalyticsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.UserAggregation objects
     * contained in responses from the listUserAnalytics operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllUserAnalytics(request: requests.ListUserAnalyticsRequest): AsyncIterableIterator<model.UserAggregation>;
    /**
     * NOTE: This function is deprecated in favor of listUserAnalyticsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listUserAnalytics operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllUserAnalyticsResponses(request: requests.ListUserAnalyticsRequest): AsyncIterableIterator<responses.ListUserAnalyticsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.UserAggregation objects
     * contained in responses from the listUserAnalytics operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listUserAnalyticsRecordIterator(request: requests.ListUserAnalyticsRequest): AsyncIterableIterator<model.UserAggregation>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listUserAnalytics operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listUserAnalyticsResponseIterator(request: requests.ListUserAnalyticsRequest): AsyncIterableIterator<responses.ListUserAnalyticsResponse>;
    /**
       * Gets a list of user assessments.
  * <p>
  The ListUserAssessments operation returns only the assessments in the specified `compartmentId`.
  * The list does not include any subcompartments of the compartmentId passed.
  * <p>
  The parameter `accessLevel` specifies whether to return only those compartments for which the
  * requestor has INSPECT permissions on at least one resource directly
  * or indirectly (ACCESSIBLE) (the resource can be in a subcompartment) or to return Not Authorized if
  * Principal doesn't have access to even one of the child compartments. This is valid only when
  * `compartmentIdInSubtree` is set to `true`.
  * <p>
  The parameter `compartmentIdInSubtree` applies when you perform ListUserAssessments on the
  * `compartmentId` passed and when it is set to true, the entire hierarchy of compartments can be returned.
  * To get a full list of all compartments and subcompartments in the tenancy (root compartment),
  * set the parameter `compartmentIdInSubtree` to true and `accessLevel` to ACCESSIBLE.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ListUserAssessmentsRequest
       * @return ListUserAssessmentsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ListUserAssessments.ts.html |here} to see how to use ListUserAssessments API.
       */
    listUserAssessments(listUserAssessmentsRequest: requests.ListUserAssessmentsRequest): Promise<responses.ListUserAssessmentsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listUserAssessmentsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.UserAssessmentSummary objects
     * contained in responses from the listUserAssessments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllUserAssessments(request: requests.ListUserAssessmentsRequest): AsyncIterableIterator<model.UserAssessmentSummary>;
    /**
     * NOTE: This function is deprecated in favor of listUserAssessmentsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listUserAssessments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllUserAssessmentsResponses(request: requests.ListUserAssessmentsRequest): AsyncIterableIterator<responses.ListUserAssessmentsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.UserAssessmentSummary objects
     * contained in responses from the listUserAssessments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listUserAssessmentsRecordIterator(request: requests.ListUserAssessmentsRequest): AsyncIterableIterator<model.UserAssessmentSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listUserAssessments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listUserAssessmentsResponseIterator(request: requests.ListUserAssessmentsRequest): AsyncIterableIterator<responses.ListUserAssessmentsResponse>;
    /**
     * Gets a list of users of the specified user assessment. The result contains the database user details for each user, such
     * as user type, account status, last login time, user creation time, authentication type, user profile, and the date and time
     * of the latest password change. It also contains the user category derived from these user details as well as privileges
     * granted to each user.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListUsersRequest
     * @return ListUsersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ListUsers.ts.html |here} to see how to use ListUsers API.
     */
    listUsers(listUsersRequest: requests.ListUsersRequest): Promise<responses.ListUsersResponse>;
    /**
     * NOTE: This function is deprecated in favor of listUsersRecordIterator function.
     * Creates a new async iterator which will iterate over the models.UserSummary objects
     * contained in responses from the listUsers operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllUsers(request: requests.ListUsersRequest): AsyncIterableIterator<model.UserSummary>;
    /**
     * NOTE: This function is deprecated in favor of listUsersResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listUsers operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllUsersResponses(request: requests.ListUsersRequest): AsyncIterableIterator<responses.ListUsersResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.UserSummary objects
     * contained in responses from the listUsers operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listUsersRecordIterator(request: requests.ListUsersRequest): AsyncIterableIterator<model.UserSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listUsers operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listUsersResponseIterator(request: requests.ListUsersRequest): AsyncIterableIterator<responses.ListUsersResponse>;
    /**
     * Gets a list of errors for the specified work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestErrorsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrors(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<model.WorkRequestError>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestErrorsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrorsResponses(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestErrorsRecordIterator(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<model.WorkRequestError>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestErrorsResponseIterator(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Gets a list of log entries for the specified work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestLogsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogs(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<model.WorkRequestLogEntry>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestLogsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogsResponses(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestLogsRecordIterator(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<model.WorkRequestLogEntry>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestLogsResponseIterator(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Gets a list of work requests.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestSummary objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequests(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<model.WorkRequestSummary>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestsResponses(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestSummary objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestsRecordIterator(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<model.WorkRequestSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestsResponseIterator(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Runs a security assessment, refreshes the latest assessment, and saves it for future reference.
     * The assessment runs with a securityAssessmentId of type LATEST. Before you start, first call the ListSecurityAssessments operation with filter \"type = latest\" to get the security assessment id for the target's latest assessment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RefreshSecurityAssessmentRequest
     * @return RefreshSecurityAssessmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/RefreshSecurityAssessment.ts.html |here} to see how to use RefreshSecurityAssessment API.
     */
    refreshSecurityAssessment(refreshSecurityAssessmentRequest: requests.RefreshSecurityAssessmentRequest): Promise<responses.RefreshSecurityAssessmentResponse>;
    /**
     * Refreshes the latest assessment and saves it for future reference. This operation runs with a userAssessmentId of type LATEST.
     * Before you start, first call the ListUserAssessments operation with filter \"type = latest\" to get the user assessment ID for
     * the target's latest assessment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RefreshUserAssessmentRequest
     * @return RefreshUserAssessmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/RefreshUserAssessment.ts.html |here} to see how to use RefreshUserAssessment API.
     */
    refreshUserAssessment(refreshUserAssessmentRequest: requests.RefreshUserAssessmentRequest): Promise<responses.RefreshUserAssessmentResponse>;
    /**
     * Sets the saved security assessment as the baseline in the compartment where the the specified assessment resides. The security assessment needs to be of type 'SAVED'.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SetSecurityAssessmentBaselineRequest
     * @return SetSecurityAssessmentBaselineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/SetSecurityAssessmentBaseline.ts.html |here} to see how to use SetSecurityAssessmentBaseline API.
     */
    setSecurityAssessmentBaseline(setSecurityAssessmentBaselineRequest: requests.SetSecurityAssessmentBaselineRequest): Promise<responses.SetSecurityAssessmentBaselineResponse>;
    /**
     * Sets the saved user assessment as the baseline in the compartment where the specified assessment resides. The user assessment needs to be of type 'SAVED'.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SetUserAssessmentBaselineRequest
     * @return SetUserAssessmentBaselineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/SetUserAssessmentBaseline.ts.html |here} to see how to use SetUserAssessmentBaseline API.
     */
    setUserAssessmentBaseline(setUserAssessmentBaselineRequest: requests.SetUserAssessmentBaselineRequest): Promise<responses.SetUserAssessmentBaselineResponse>;
    /**
     * Removes the baseline setting for the saved security assessment. The saved security assessment is no longer considered a baseline.
     * Sets the if-match parameter to the value of the etag from a previous GET or POST response for that resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UnsetSecurityAssessmentBaselineRequest
     * @return UnsetSecurityAssessmentBaselineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/UnsetSecurityAssessmentBaseline.ts.html |here} to see how to use UnsetSecurityAssessmentBaseline API.
     */
    unsetSecurityAssessmentBaseline(unsetSecurityAssessmentBaselineRequest: requests.UnsetSecurityAssessmentBaselineRequest): Promise<responses.UnsetSecurityAssessmentBaselineResponse>;
    /**
     * Removes the baseline setting for the saved user assessment. The saved user assessment is no longer considered a baseline.
     * Sets the if-match parameter to the value of the etag from a previous GET or POST response for that resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UnsetUserAssessmentBaselineRequest
     * @return UnsetUserAssessmentBaselineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/UnsetUserAssessmentBaseline.ts.html |here} to see how to use UnsetUserAssessmentBaseline API.
     */
    unsetUserAssessmentBaseline(unsetUserAssessmentBaselineRequest: requests.UnsetUserAssessmentBaselineRequest): Promise<responses.UnsetUserAssessmentBaselineResponse>;
    /**
     * Updates one or more attributes of the specified Data Safe private endpoint.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDataSafePrivateEndpointRequest
     * @return UpdateDataSafePrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/UpdateDataSafePrivateEndpoint.ts.html |here} to see how to use UpdateDataSafePrivateEndpoint API.
     */
    updateDataSafePrivateEndpoint(updateDataSafePrivateEndpointRequest: requests.UpdateDataSafePrivateEndpointRequest): Promise<responses.UpdateDataSafePrivateEndpointResponse>;
    /**
     * Updates one or more attributes of the specified on-premises connector.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateOnPremConnectorRequest
     * @return UpdateOnPremConnectorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/UpdateOnPremConnector.ts.html |here} to see how to use UpdateOnPremConnector API.
     */
    updateOnPremConnector(updateOnPremConnectorRequest: requests.UpdateOnPremConnectorRequest): Promise<responses.UpdateOnPremConnectorResponse>;
    /**
     * Updates the wallet for the specified on-premises connector to a new version.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateOnPremConnectorWalletRequest
     * @return UpdateOnPremConnectorWalletResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/UpdateOnPremConnectorWallet.ts.html |here} to see how to use UpdateOnPremConnectorWallet API.
     */
    updateOnPremConnectorWallet(updateOnPremConnectorWalletRequest: requests.UpdateOnPremConnectorWalletRequest): Promise<responses.UpdateOnPremConnectorWalletResponse>;
    /**
     * Updates one or more attributes of the specified security assessment. This operation allows to update the security assessment displayName, description, or schedule.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateSecurityAssessmentRequest
     * @return UpdateSecurityAssessmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/UpdateSecurityAssessment.ts.html |here} to see how to use UpdateSecurityAssessment API.
     */
    updateSecurityAssessment(updateSecurityAssessmentRequest: requests.UpdateSecurityAssessmentRequest): Promise<responses.UpdateSecurityAssessmentResponse>;
    /**
     * Updates one or more attributes of the specified Data Safe target database.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateTargetDatabaseRequest
     * @return UpdateTargetDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/UpdateTargetDatabase.ts.html |here} to see how to use UpdateTargetDatabase API.
     */
    updateTargetDatabase(updateTargetDatabaseRequest: requests.UpdateTargetDatabaseRequest): Promise<responses.UpdateTargetDatabaseResponse>;
    /**
     * Updates one or more attributes of the specified user assessment. This operation allows to update the user assessment displayName, description, or schedule.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateUserAssessmentRequest
     * @return UpdateUserAssessmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/datasafe/UpdateUserAssessment.ts.html |here} to see how to use UpdateUserAssessment API.
     */
    updateUserAssessment(updateUserAssessmentRequest: requests.UpdateUserAssessmentRequest): Promise<responses.UpdateUserAssessmentResponse>;
}
