/**
 * Operations Insights API
 * Use the Operations Insights API to perform data extraction operations to obtain database
resource utilization, performance statistics, and reference information. For more information,
see [About Oracle Cloud Infrastructure Operations Insights](https://docs.cloud.oracle.com/en-us/iaas/operations-insights/doc/operations-insights.html).

 * OpenAPI spec version: 20200630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { OperationsInsightsWaiter } from "./operationsinsights-waiter";
export declare enum OperationsInsightsApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class OperationsInsightsClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": OperationsInsightsWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new OperationsInsightsWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): OperationsInsightsWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): OperationsInsightsWaiter;
    /**
     * Add new members (e.g. databases and hosts) to an Exadata system in Operations Insights. Exadata-related metric collection and analysis will be started.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddExadataInsightMembersRequest
     * @return AddExadataInsightMembersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/AddExadataInsightMembers.ts.html |here} to see how to use AddExadataInsightMembers API.
     */
    addExadataInsightMembers(addExadataInsightMembersRequest: requests.AddExadataInsightMembersRequest): Promise<responses.AddExadataInsightMembersResponse>;
    /**
     * Moves a DatabaseInsight resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeDatabaseInsightCompartmentRequest
     * @return ChangeDatabaseInsightCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ChangeDatabaseInsightCompartment.ts.html |here} to see how to use ChangeDatabaseInsightCompartment API.
     */
    changeDatabaseInsightCompartment(changeDatabaseInsightCompartmentRequest: requests.ChangeDatabaseInsightCompartmentRequest): Promise<responses.ChangeDatabaseInsightCompartmentResponse>;
    /**
     * Moves a EnterpriseManagerBridge resource from one compartment to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeEnterpriseManagerBridgeCompartmentRequest
     * @return ChangeEnterpriseManagerBridgeCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ChangeEnterpriseManagerBridgeCompartment.ts.html |here} to see how to use ChangeEnterpriseManagerBridgeCompartment API.
     */
    changeEnterpriseManagerBridgeCompartment(changeEnterpriseManagerBridgeCompartmentRequest: requests.ChangeEnterpriseManagerBridgeCompartmentRequest): Promise<responses.ChangeEnterpriseManagerBridgeCompartmentResponse>;
    /**
     * Moves an Exadata insight resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeExadataInsightCompartmentRequest
     * @return ChangeExadataInsightCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ChangeExadataInsightCompartment.ts.html |here} to see how to use ChangeExadataInsightCompartment API.
     */
    changeExadataInsightCompartment(changeExadataInsightCompartmentRequest: requests.ChangeExadataInsightCompartmentRequest): Promise<responses.ChangeExadataInsightCompartmentResponse>;
    /**
     * Moves a HostInsight resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeHostInsightCompartmentRequest
     * @return ChangeHostInsightCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ChangeHostInsightCompartment.ts.html |here} to see how to use ChangeHostInsightCompartment API.
     */
    changeHostInsightCompartment(changeHostInsightCompartmentRequest: requests.ChangeHostInsightCompartmentRequest): Promise<responses.ChangeHostInsightCompartmentResponse>;
    /**
     * Create a AWR hub resource for the tenant in Operations Insights.
     * This resource will be created in root compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateAwrHubRequest
     * @return CreateAwrHubResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/CreateAwrHub.ts.html |here} to see how to use CreateAwrHub API.
     */
    createAwrHub(createAwrHubRequest: requests.CreateAwrHubRequest): Promise<responses.CreateAwrHubResponse>;
    /**
     * Create a Database Insight resource for a database in Operations Insights. The database will be enabled in Operations Insights. Database metric collection and analysis will be started.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDatabaseInsightRequest
     * @return CreateDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/CreateDatabaseInsight.ts.html |here} to see how to use CreateDatabaseInsight API.
     */
    createDatabaseInsight(createDatabaseInsightRequest: requests.CreateDatabaseInsightRequest): Promise<responses.CreateDatabaseInsightResponse>;
    /**
     * Create a Enterprise Manager bridge in Operations Insights.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateEnterpriseManagerBridgeRequest
     * @return CreateEnterpriseManagerBridgeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/CreateEnterpriseManagerBridge.ts.html |here} to see how to use CreateEnterpriseManagerBridge API.
     */
    createEnterpriseManagerBridge(createEnterpriseManagerBridgeRequest: requests.CreateEnterpriseManagerBridgeRequest): Promise<responses.CreateEnterpriseManagerBridgeResponse>;
    /**
     * Create an Exadata insight resource for an Exadata system in Operations Insights. The Exadata system will be enabled in Operations Insights. Exadata-related metric collection and analysis will be started.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateExadataInsightRequest
     * @return CreateExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/CreateExadataInsight.ts.html |here} to see how to use CreateExadataInsight API.
     */
    createExadataInsight(createExadataInsightRequest: requests.CreateExadataInsightRequest): Promise<responses.CreateExadataInsightResponse>;
    /**
     * Create a Host Insight resource for a host in Operations Insights. The host will be enabled in Operations Insights. Host metric collection and analysis will be started.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateHostInsightRequest
     * @return CreateHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/CreateHostInsight.ts.html |here} to see how to use CreateHostInsight API.
     */
    createHostInsight(createHostInsightRequest: requests.CreateHostInsightRequest): Promise<responses.CreateHostInsightResponse>;
    /**
     * Create a Operations Insights Warehouse resource for the tenant in Operations Insights. New ADW will be provisioned for this tenant.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateOperationsInsightsWarehouseRequest
     * @return CreateOperationsInsightsWarehouseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/CreateOperationsInsightsWarehouse.ts.html |here} to see how to use CreateOperationsInsightsWarehouse API.
     */
    createOperationsInsightsWarehouse(createOperationsInsightsWarehouseRequest: requests.CreateOperationsInsightsWarehouseRequest): Promise<responses.CreateOperationsInsightsWarehouseResponse>;
    /**
     * Create a Operations Insights Warehouse user resource for the tenant in Operations Insights.
     * This resource will be created in root compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateOperationsInsightsWarehouseUserRequest
     * @return CreateOperationsInsightsWarehouseUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/CreateOperationsInsightsWarehouseUser.ts.html |here} to see how to use CreateOperationsInsightsWarehouseUser API.
     */
    createOperationsInsightsWarehouseUser(createOperationsInsightsWarehouseUserRequest: requests.CreateOperationsInsightsWarehouseUserRequest): Promise<responses.CreateOperationsInsightsWarehouseUserResponse>;
    /**
     * Deletes an AWR hub.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteAwrHubRequest
     * @return DeleteAwrHubResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/DeleteAwrHub.ts.html |here} to see how to use DeleteAwrHub API.
     */
    deleteAwrHub(deleteAwrHubRequest: requests.DeleteAwrHubRequest): Promise<responses.DeleteAwrHubResponse>;
    /**
     * Deletes a database insight. The database insight will be deleted and cannot be enabled again.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDatabaseInsightRequest
     * @return DeleteDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/DeleteDatabaseInsight.ts.html |here} to see how to use DeleteDatabaseInsight API.
     */
    deleteDatabaseInsight(deleteDatabaseInsightRequest: requests.DeleteDatabaseInsightRequest): Promise<responses.DeleteDatabaseInsightResponse>;
    /**
     * Deletes an Operations Insights Enterprise Manager bridge. If any database insight is still referencing this bridge, the operation will fail.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteEnterpriseManagerBridgeRequest
     * @return DeleteEnterpriseManagerBridgeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/DeleteEnterpriseManagerBridge.ts.html |here} to see how to use DeleteEnterpriseManagerBridge API.
     */
    deleteEnterpriseManagerBridge(deleteEnterpriseManagerBridgeRequest: requests.DeleteEnterpriseManagerBridgeRequest): Promise<responses.DeleteEnterpriseManagerBridgeResponse>;
    /**
     * Deletes an Exadata insight. The Exadata insight will be deleted and cannot be enabled again.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteExadataInsightRequest
     * @return DeleteExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/DeleteExadataInsight.ts.html |here} to see how to use DeleteExadataInsight API.
     */
    deleteExadataInsight(deleteExadataInsightRequest: requests.DeleteExadataInsightRequest): Promise<responses.DeleteExadataInsightResponse>;
    /**
     * Deletes a host insight. The host insight will be deleted and cannot be enabled again.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteHostInsightRequest
     * @return DeleteHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/DeleteHostInsight.ts.html |here} to see how to use DeleteHostInsight API.
     */
    deleteHostInsight(deleteHostInsightRequest: requests.DeleteHostInsightRequest): Promise<responses.DeleteHostInsightResponse>;
    /**
     * Deletes an Operations Insights Warehouse. There is only expected to be 1 warehouse per tenant.
     * The warehouse is expected to be in the root compartment.
     * User must delete AWR Hub resource for this warehouse before calling this operation.
     * User must delete the warehouse users before calling this operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteOperationsInsightsWarehouseRequest
     * @return DeleteOperationsInsightsWarehouseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/DeleteOperationsInsightsWarehouse.ts.html |here} to see how to use DeleteOperationsInsightsWarehouse API.
     */
    deleteOperationsInsightsWarehouse(deleteOperationsInsightsWarehouseRequest: requests.DeleteOperationsInsightsWarehouseRequest): Promise<responses.DeleteOperationsInsightsWarehouseResponse>;
    /**
     * Deletes an Operations Insights Warehouse User.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteOperationsInsightsWarehouseUserRequest
     * @return DeleteOperationsInsightsWarehouseUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/DeleteOperationsInsightsWarehouseUser.ts.html |here} to see how to use DeleteOperationsInsightsWarehouseUser API.
     */
    deleteOperationsInsightsWarehouseUser(deleteOperationsInsightsWarehouseUserRequest: requests.DeleteOperationsInsightsWarehouseUserRequest): Promise<responses.DeleteOperationsInsightsWarehouseUserResponse>;
    /**
     * Disables a database in Operations Insights. Database metric collection and analysis will be stopped.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableDatabaseInsightRequest
     * @return DisableDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/DisableDatabaseInsight.ts.html |here} to see how to use DisableDatabaseInsight API.
     */
    disableDatabaseInsight(disableDatabaseInsightRequest: requests.DisableDatabaseInsightRequest): Promise<responses.DisableDatabaseInsightResponse>;
    /**
     * Disables an Exadata system in Operations Insights. Exadata-related metric collection and analysis will be stopped.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableExadataInsightRequest
     * @return DisableExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/DisableExadataInsight.ts.html |here} to see how to use DisableExadataInsight API.
     */
    disableExadataInsight(disableExadataInsightRequest: requests.DisableExadataInsightRequest): Promise<responses.DisableExadataInsightResponse>;
    /**
     * Disables a host in Operations Insights. Host metric collection and analysis will be stopped.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableHostInsightRequest
     * @return DisableHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/DisableHostInsight.ts.html |here} to see how to use DisableHostInsight API.
     */
    disableHostInsight(disableHostInsightRequest: requests.DisableHostInsightRequest): Promise<responses.DisableHostInsightResponse>;
    /**
     * Download the ADW wallet for Operations Insights Warehouse using which the Hub data is exposed.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DownloadOperationsInsightsWarehouseWalletRequest
     * @return DownloadOperationsInsightsWarehouseWalletResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/DownloadOperationsInsightsWarehouseWallet.ts.html |here} to see how to use DownloadOperationsInsightsWarehouseWallet API.
     */
    downloadOperationsInsightsWarehouseWallet(downloadOperationsInsightsWarehouseWalletRequest: requests.DownloadOperationsInsightsWarehouseWalletRequest): Promise<responses.DownloadOperationsInsightsWarehouseWalletResponse>;
    /**
     * Enables a database in Operations Insights. Database metric collection and analysis will be started.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableDatabaseInsightRequest
     * @return EnableDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/EnableDatabaseInsight.ts.html |here} to see how to use EnableDatabaseInsight API.
     */
    enableDatabaseInsight(enableDatabaseInsightRequest: requests.EnableDatabaseInsightRequest): Promise<responses.EnableDatabaseInsightResponse>;
    /**
     * Enables an Exadata system in Operations Insights. Exadata-related metric collection and analysis will be started.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableExadataInsightRequest
     * @return EnableExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/EnableExadataInsight.ts.html |here} to see how to use EnableExadataInsight API.
     */
    enableExadataInsight(enableExadataInsightRequest: requests.EnableExadataInsightRequest): Promise<responses.EnableExadataInsightResponse>;
    /**
     * Enables a host in Operations Insights. Host metric collection and analysis will be started.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableHostInsightRequest
     * @return EnableHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/EnableHostInsight.ts.html |here} to see how to use EnableHostInsight API.
     */
    enableHostInsight(enableHostInsightRequest: requests.EnableHostInsightRequest): Promise<responses.EnableHostInsightResponse>;
    /**
     * Gets details of an AWR hub.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAwrHubRequest
     * @return GetAwrHubResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/GetAwrHub.ts.html |here} to see how to use GetAwrHub API.
     */
    getAwrHub(getAwrHubRequest: requests.GetAwrHubRequest): Promise<responses.GetAwrHubResponse>;
    /**
     * Gets the AWR report for the specified source database in the AWR hub. The difference between the timeGreaterThanOrEqualTo and timeLessThanOrEqualTo should not be greater than 7 days.
     * Either beginSnapshotIdentifierGreaterThanOrEqualTo & endSnapshotIdentifierLessThanOrEqualTo params Or timeGreaterThanOrEqualTo & timeLessThanOrEqualTo params are required.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAwrReportRequest
     * @return GetAwrReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/GetAwrReport.ts.html |here} to see how to use GetAwrReport API.
     */
    getAwrReport(getAwrReportRequest: requests.GetAwrReportRequest): Promise<responses.GetAwrReportResponse>;
    /**
     * Gets details of a database insight.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDatabaseInsightRequest
     * @return GetDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/GetDatabaseInsight.ts.html |here} to see how to use GetDatabaseInsight API.
     */
    getDatabaseInsight(getDatabaseInsightRequest: requests.GetDatabaseInsightRequest): Promise<responses.GetDatabaseInsightResponse>;
    /**
     * Gets details of an Operations Insights Enterprise Manager bridge.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetEnterpriseManagerBridgeRequest
     * @return GetEnterpriseManagerBridgeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/GetEnterpriseManagerBridge.ts.html |here} to see how to use GetEnterpriseManagerBridge API.
     */
    getEnterpriseManagerBridge(getEnterpriseManagerBridgeRequest: requests.GetEnterpriseManagerBridgeRequest): Promise<responses.GetEnterpriseManagerBridgeResponse>;
    /**
     * Gets details of an Exadata insight.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExadataInsightRequest
     * @return GetExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/GetExadataInsight.ts.html |here} to see how to use GetExadataInsight API.
     */
    getExadataInsight(getExadataInsightRequest: requests.GetExadataInsightRequest): Promise<responses.GetExadataInsightResponse>;
    /**
     * Gets details of a host insight.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetHostInsightRequest
     * @return GetHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/GetHostInsight.ts.html |here} to see how to use GetHostInsight API.
     */
    getHostInsight(getHostInsightRequest: requests.GetHostInsightRequest): Promise<responses.GetHostInsightResponse>;
    /**
     * Gets details of an Operations Insights Warehouse.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetOperationsInsightsWarehouseRequest
     * @return GetOperationsInsightsWarehouseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/GetOperationsInsightsWarehouse.ts.html |here} to see how to use GetOperationsInsightsWarehouse API.
     */
    getOperationsInsightsWarehouse(getOperationsInsightsWarehouseRequest: requests.GetOperationsInsightsWarehouseRequest): Promise<responses.GetOperationsInsightsWarehouseResponse>;
    /**
     * Gets details of an Operations Insights Warehouse User.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetOperationsInsightsWarehouseUserRequest
     * @return GetOperationsInsightsWarehouseUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/GetOperationsInsightsWarehouseUser.ts.html |here} to see how to use GetOperationsInsightsWarehouseUser API.
     */
    getOperationsInsightsWarehouseUser(getOperationsInsightsWarehouseUserRequest: requests.GetOperationsInsightsWarehouseUserRequest): Promise<responses.GetOperationsInsightsWarehouseUserResponse>;
    /**
     * Gets the status of the work request with the given ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * This is a generic ingest endpoint for all database configuration metrics.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param IngestDatabaseConfigurationRequest
     * @return IngestDatabaseConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/IngestDatabaseConfiguration.ts.html |here} to see how to use IngestDatabaseConfiguration API.
     */
    ingestDatabaseConfiguration(ingestDatabaseConfigurationRequest: requests.IngestDatabaseConfigurationRequest): Promise<responses.IngestDatabaseConfigurationResponse>;
    /**
     * This is a generic ingest endpoint for all the host configuration metrics
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param IngestHostConfigurationRequest
     * @return IngestHostConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/IngestHostConfiguration.ts.html |here} to see how to use IngestHostConfiguration API.
     */
    ingestHostConfiguration(ingestHostConfigurationRequest: requests.IngestHostConfigurationRequest): Promise<responses.IngestHostConfigurationResponse>;
    /**
     * This is a generic ingest endpoint for all the host performance metrics
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param IngestHostMetricsRequest
     * @return IngestHostMetricsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/IngestHostMetrics.ts.html |here} to see how to use IngestHostMetrics API.
     */
    ingestHostMetrics(ingestHostMetricsRequest: requests.IngestHostMetricsRequest): Promise<responses.IngestHostMetricsResponse>;
    /**
     * The sqlbucket endpoint takes in a JSON payload, persists it in Operations Insights ingest pipeline.
     * Either databaseId or id must be specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param IngestSqlBucketRequest
     * @return IngestSqlBucketResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/IngestSqlBucket.ts.html |here} to see how to use IngestSqlBucket API.
     */
    ingestSqlBucket(ingestSqlBucketRequest: requests.IngestSqlBucketRequest): Promise<responses.IngestSqlBucketResponse>;
    /**
     * The SqlPlanLines endpoint takes in a JSON payload, persists it in Operation Insights ingest pipeline.
     * Either databaseId or id must be specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param IngestSqlPlanLinesRequest
     * @return IngestSqlPlanLinesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/IngestSqlPlanLines.ts.html |here} to see how to use IngestSqlPlanLines API.
     */
    ingestSqlPlanLines(ingestSqlPlanLinesRequest: requests.IngestSqlPlanLinesRequest): Promise<responses.IngestSqlPlanLinesResponse>;
    /**
     * The SQL Stats endpoint takes in a JSON payload, persists it in Operations Insights ingest pipeline.
     * Either databaseId or id must be specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param IngestSqlStatsRequest
     * @return IngestSqlStatsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/IngestSqlStats.ts.html |here} to see how to use IngestSqlStats API.
     */
    ingestSqlStats(ingestSqlStatsRequest: requests.IngestSqlStatsRequest): Promise<responses.IngestSqlStatsResponse>;
    /**
     * The SqlText endpoint takes in a JSON payload, persists it in Operation Insights ingest pipeline.
     * Either databaseId or id must be specified.
     * Disclaimer: SQL text being uploaded explicitly via APIs is not masked. Any sensitive literals contained in the sqlFullText column should be masked prior to ingestion.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param IngestSqlTextRequest
     * @return IngestSqlTextResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/IngestSqlText.ts.html |here} to see how to use IngestSqlText API.
     */
    ingestSqlText(ingestSqlTextRequest: requests.IngestSqlTextRequest): Promise<responses.IngestSqlTextResponse>;
    /**
     * Gets a list of AWR hubs. Either compartmentId or id must be specified. All these resources are expected to be in root compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAwrHubsRequest
     * @return ListAwrHubsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListAwrHubs.ts.html |here} to see how to use ListAwrHubs API.
     */
    listAwrHubs(listAwrHubsRequest: requests.ListAwrHubsRequest): Promise<responses.ListAwrHubsResponse>;
    /**
     * Lists AWR snapshots for the specified source database in the AWR hub. The difference between the timeGreaterThanOrEqualTo and timeLessThanOrEqualTo should not exceed an elapsed range of 1 day.
     * The timeGreaterThanOrEqualTo & timeLessThanOrEqualTo params are optional. If these params are not provided, by default last 1 day snapshots will be returned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAwrSnapshotsRequest
     * @return ListAwrSnapshotsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListAwrSnapshots.ts.html |here} to see how to use ListAwrSnapshots API.
     */
    listAwrSnapshots(listAwrSnapshotsRequest: requests.ListAwrSnapshotsRequest): Promise<responses.ListAwrSnapshotsResponse>;
    /**
     * Gets a list of database insight configurations based on the query parameters specified. Either compartmentId or databaseInsightId query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of database insight configurations in that compartment and in all sub-compartments will be returned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDatabaseConfigurationsRequest
     * @return ListDatabaseConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListDatabaseConfigurations.ts.html |here} to see how to use ListDatabaseConfigurations API.
     */
    listDatabaseConfigurations(listDatabaseConfigurationsRequest: requests.ListDatabaseConfigurationsRequest): Promise<responses.ListDatabaseConfigurationsResponse>;
    /**
     * Gets a list of database insights based on the query parameters specified. Either compartmentId or id query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of database insights in that compartment and in all sub-compartments will be returned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDatabaseInsightsRequest
     * @return ListDatabaseInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListDatabaseInsights.ts.html |here} to see how to use ListDatabaseInsights API.
     */
    listDatabaseInsights(listDatabaseInsightsRequest: requests.ListDatabaseInsightsRequest): Promise<responses.ListDatabaseInsightsResponse>;
    /**
     * Gets a list of Operations Insights Enterprise Manager bridges. Either compartmentId or id must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of bridges in that compartment and in all sub-compartments will be returned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListEnterpriseManagerBridgesRequest
     * @return ListEnterpriseManagerBridgesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListEnterpriseManagerBridges.ts.html |here} to see how to use ListEnterpriseManagerBridges API.
     */
    listEnterpriseManagerBridges(listEnterpriseManagerBridgesRequest: requests.ListEnterpriseManagerBridgesRequest): Promise<responses.ListEnterpriseManagerBridgesResponse>;
    /**
     * Gets a list of exadata insight configurations. Either compartmentId or exadataInsightsId query parameter must be specified.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExadataConfigurationsRequest
     * @return ListExadataConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListExadataConfigurations.ts.html |here} to see how to use ListExadataConfigurations API.
     */
    listExadataConfigurations(listExadataConfigurationsRequest: requests.ListExadataConfigurationsRequest): Promise<responses.ListExadataConfigurationsResponse>;
    /**
     * Gets a list of Exadata insights based on the query parameters specified. Either compartmentId or id query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of Exadata insights in that compartment and in all sub-compartments will be returned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExadataInsightsRequest
     * @return ListExadataInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListExadataInsights.ts.html |here} to see how to use ListExadataInsights API.
     */
    listExadataInsights(listExadataInsightsRequest: requests.ListExadataInsightsRequest): Promise<responses.ListExadataInsightsResponse>;
    /**
     * Gets a list of host insight configurations based on the query parameters specified. Either compartmentId or hostInsightId query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of host insight configurations in that compartment and in all sub-compartments will be returned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListHostConfigurationsRequest
     * @return ListHostConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListHostConfigurations.ts.html |here} to see how to use ListHostConfigurations API.
     */
    listHostConfigurations(listHostConfigurationsRequest: requests.ListHostConfigurationsRequest): Promise<responses.ListHostConfigurationsResponse>;
    /**
     * Gets a list of host insights based on the query parameters specified. Either compartmentId or id query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of host insights in that compartment and in all sub-compartments will be returned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListHostInsightsRequest
     * @return ListHostInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListHostInsights.ts.html |here} to see how to use ListHostInsights API.
     */
    listHostInsights(listHostInsightsRequest: requests.ListHostInsightsRequest): Promise<responses.ListHostInsightsResponse>;
    /**
     * Get a list of hosted entities details.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListHostedEntitiesRequest
     * @return ListHostedEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListHostedEntities.ts.html |here} to see how to use ListHostedEntities API.
     */
    listHostedEntities(listHostedEntitiesRequest: requests.ListHostedEntitiesRequest): Promise<responses.ListHostedEntitiesResponse>;
    /**
     * Gets a list of agent entities available to add a new hostInsight.  An agent entity is \"available\"
     * and will be shown if all the following conditions are true:
     *    1.  The agent OCID is not already being used for an existing hostInsight.
     *    2.  The agent availabilityStatus = 'ACTIVE'
     *    3.  The agent lifecycleState = 'ACTIVE'
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListImportableAgentEntitiesRequest
     * @return ListImportableAgentEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListImportableAgentEntities.ts.html |here} to see how to use ListImportableAgentEntities API.
     */
    listImportableAgentEntities(listImportableAgentEntitiesRequest: requests.ListImportableAgentEntitiesRequest): Promise<responses.ListImportableAgentEntitiesResponse>;
    /**
     * Gets a list of importable entities for an Operations Insights Enterprise Manager bridge that have not been imported before.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListImportableEnterpriseManagerEntitiesRequest
     * @return ListImportableEnterpriseManagerEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListImportableEnterpriseManagerEntities.ts.html |here} to see how to use ListImportableEnterpriseManagerEntities API.
     */
    listImportableEnterpriseManagerEntities(listImportableEnterpriseManagerEntitiesRequest: requests.ListImportableEnterpriseManagerEntitiesRequest): Promise<responses.ListImportableEnterpriseManagerEntitiesResponse>;
    /**
     * Gets a list of Operations Insights Warehouse users. Either compartmentId or id must be specified. All these resources are expected to be in root compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListOperationsInsightsWarehouseUsersRequest
     * @return ListOperationsInsightsWarehouseUsersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListOperationsInsightsWarehouseUsers.ts.html |here} to see how to use ListOperationsInsightsWarehouseUsers API.
     */
    listOperationsInsightsWarehouseUsers(listOperationsInsightsWarehouseUsersRequest: requests.ListOperationsInsightsWarehouseUsersRequest): Promise<responses.ListOperationsInsightsWarehouseUsersResponse>;
    /**
     * Gets a list of Operations Insights warehouses. Either compartmentId or id must be specified.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListOperationsInsightsWarehousesRequest
     * @return ListOperationsInsightsWarehousesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListOperationsInsightsWarehouses.ts.html |here} to see how to use ListOperationsInsightsWarehouses API.
     */
    listOperationsInsightsWarehouses(listOperationsInsightsWarehousesRequest: requests.ListOperationsInsightsWarehousesRequest): Promise<responses.ListOperationsInsightsWarehousesResponse>;
    /**
     * Query SQL Warehouse to list the plan xml for a given SQL execution plan. This returns a SqlPlanCollection object, but is currently limited to a single plan.
     * Either databaseId or id must be specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSqlPlansRequest
     * @return ListSqlPlansResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListSqlPlans.ts.html |here} to see how to use ListSqlPlans API.
     */
    listSqlPlans(listSqlPlansRequest: requests.ListSqlPlansRequest): Promise<responses.ListSqlPlansResponse>;
    /**
     * Search SQL by SQL Identifier across databases in a compartment and in all sub-compartments if specified.
     * And get the SQL Text and the details of the databases executing the SQL for a given time period.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSqlSearchesRequest
     * @return ListSqlSearchesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListSqlSearches.ts.html |here} to see how to use ListSqlSearches API.
     */
    listSqlSearches(listSqlSearchesRequest: requests.ListSqlSearchesRequest): Promise<responses.ListSqlSearchesResponse>;
    /**
     * Query SQL Warehouse to get the full SQL Text for a SQL in a compartment and in all sub-compartments if specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSqlTextsRequest
     * @return ListSqlTextsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListSqlTexts.ts.html |here} to see how to use ListSqlTexts API.
     */
    listSqlTexts(listSqlTextsRequest: requests.ListSqlTextsRequest): Promise<responses.ListSqlTextsResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment. Either compartmentId or id must be specified. Only one of id, resourceId or relatedResourceId can be specified optionally.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Rotate the ADW wallet for Operations Insights Warehouse using which the Hub data is exposed.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RotateOperationsInsightsWarehouseWalletRequest
     * @return RotateOperationsInsightsWarehouseWalletResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/RotateOperationsInsightsWarehouseWallet.ts.html |here} to see how to use RotateOperationsInsightsWarehouseWallet API.
     */
    rotateOperationsInsightsWarehouseWallet(rotateOperationsInsightsWarehouseWalletRequest: requests.RotateOperationsInsightsWarehouseWalletRequest): Promise<responses.RotateOperationsInsightsWarehouseWalletResponse>;
    /**
     * Gets a list of summary of AWR Sources.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeAwrSourcesSummariesRequest
     * @return SummarizeAwrSourcesSummariesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeAwrSourcesSummaries.ts.html |here} to see how to use SummarizeAwrSourcesSummaries API.
     */
    summarizeAwrSourcesSummaries(summarizeAwrSourcesSummariesRequest: requests.SummarizeAwrSourcesSummariesRequest): Promise<responses.SummarizeAwrSourcesSummariesResponse>;
    /**
     * Returns response with time series data (endTimestamp, capacity, baseCapacity) for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeDatabaseInsightResourceCapacityTrendRequest
     * @return SummarizeDatabaseInsightResourceCapacityTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeDatabaseInsightResourceCapacityTrend.ts.html |here} to see how to use SummarizeDatabaseInsightResourceCapacityTrend API.
     */
    summarizeDatabaseInsightResourceCapacityTrend(summarizeDatabaseInsightResourceCapacityTrendRequest: requests.SummarizeDatabaseInsightResourceCapacityTrendRequest): Promise<responses.SummarizeDatabaseInsightResourceCapacityTrendResponse>;
    /**
     * Get Forecast predictions for CPU and Storage resources since a time in the past.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeDatabaseInsightResourceForecastTrendRequest
     * @return SummarizeDatabaseInsightResourceForecastTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeDatabaseInsightResourceForecastTrend.ts.html |here} to see how to use SummarizeDatabaseInsightResourceForecastTrend API.
     */
    summarizeDatabaseInsightResourceForecastTrend(summarizeDatabaseInsightResourceForecastTrendRequest: requests.SummarizeDatabaseInsightResourceForecastTrendRequest): Promise<responses.SummarizeDatabaseInsightResourceForecastTrendResponse>;
    /**
     * Lists the Resource statistics (usage,capacity, usage change percent, utilization percent, base capacity, isAutoScalingEnabled)
     * for each database filtered by utilization level in a compartment and in all sub-compartments if specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeDatabaseInsightResourceStatisticsRequest
     * @return SummarizeDatabaseInsightResourceStatisticsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeDatabaseInsightResourceStatistics.ts.html |here} to see how to use SummarizeDatabaseInsightResourceStatistics API.
     */
    summarizeDatabaseInsightResourceStatistics(summarizeDatabaseInsightResourceStatisticsRequest: requests.SummarizeDatabaseInsightResourceStatisticsRequest): Promise<responses.SummarizeDatabaseInsightResourceStatisticsResponse>;
    /**
     * A cumulative distribution function is used to rank the usage data points per database within the specified time period.
     * For each database, the minimum data point with a ranking > the percentile value is included in the summation.
     * Linear regression functions are used to calculate the usage change percentage.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeDatabaseInsightResourceUsageRequest
     * @return SummarizeDatabaseInsightResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeDatabaseInsightResourceUsage.ts.html |here} to see how to use SummarizeDatabaseInsightResourceUsage API.
     */
    summarizeDatabaseInsightResourceUsage(summarizeDatabaseInsightResourceUsageRequest: requests.SummarizeDatabaseInsightResourceUsageRequest): Promise<responses.SummarizeDatabaseInsightResourceUsageResponse>;
    /**
     * Returns response with time series data (endTimestamp, usage, capacity) for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeDatabaseInsightResourceUsageTrendRequest
     * @return SummarizeDatabaseInsightResourceUsageTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeDatabaseInsightResourceUsageTrend.ts.html |here} to see how to use SummarizeDatabaseInsightResourceUsageTrend API.
     */
    summarizeDatabaseInsightResourceUsageTrend(summarizeDatabaseInsightResourceUsageTrendRequest: requests.SummarizeDatabaseInsightResourceUsageTrendRequest): Promise<responses.SummarizeDatabaseInsightResourceUsageTrendResponse>;
    /**
     * Gets resources with current utilization (high and low) and projected utilization (high and low) for a resource type over specified time period.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeDatabaseInsightResourceUtilizationInsightRequest
     * @return SummarizeDatabaseInsightResourceUtilizationInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeDatabaseInsightResourceUtilizationInsight.ts.html |here} to see how to use SummarizeDatabaseInsightResourceUtilizationInsight API.
     */
    summarizeDatabaseInsightResourceUtilizationInsight(summarizeDatabaseInsightResourceUtilizationInsightRequest: requests.SummarizeDatabaseInsightResourceUtilizationInsightRequest): Promise<responses.SummarizeDatabaseInsightResourceUtilizationInsightResponse>;
    /**
     * Returns response with usage time series data (endTimestamp, usage, capacity) with breakdown by tablespaceName for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * Either databaseId or id must be specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeDatabaseInsightTablespaceUsageTrendRequest
     * @return SummarizeDatabaseInsightTablespaceUsageTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeDatabaseInsightTablespaceUsageTrend.ts.html |here} to see how to use SummarizeDatabaseInsightTablespaceUsageTrend API.
     */
    summarizeDatabaseInsightTablespaceUsageTrend(summarizeDatabaseInsightTablespaceUsageTrendRequest: requests.SummarizeDatabaseInsightTablespaceUsageTrendRequest): Promise<responses.SummarizeDatabaseInsightTablespaceUsageTrendResponse>;
    /**
     * Returns response with time series data (endTimestamp, capacity) for the time period specified for an exadata system for a resource metric.
     * Additionally resources can be filtered using databaseInsightId, hostInsightId or storageServerName query parameters.
     * Top five resources are returned if total exceeds the limit specified.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE. Database name is returned in name field. DatabaseInsightId, cdbName and hostName query parameter applies to ResourceType DATABASE.
     * Valid values for ResourceType HOST are CPU and MEMORY. HostName is returned in name field. HostInsightId and hostName query parameter applies to ResourceType HOST.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT. Storage server name is returned in name field for resourceMetric IOPS and THROUGHPUT
     * and asmName is returned in name field for resourceMetric STORAGE. StorageServerName query parameter applies to ResourceType STORAGE_SERVER.
     * Valid values for ResourceType DISKGROUP is STORAGE. Comma delimited (asmName,diskgroupName) is returned in name field.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeExadataInsightResourceCapacityTrendRequest
     * @return SummarizeExadataInsightResourceCapacityTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeExadataInsightResourceCapacityTrend.ts.html |here} to see how to use SummarizeExadataInsightResourceCapacityTrend API.
     */
    summarizeExadataInsightResourceCapacityTrend(summarizeExadataInsightResourceCapacityTrendRequest: requests.SummarizeExadataInsightResourceCapacityTrendRequest): Promise<responses.SummarizeExadataInsightResourceCapacityTrendResponse>;
    /**
     * Returns response with time series data (endTimestamp, capacity) for the time period specified for an exadata system or fleet aggregation for a resource metric.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeExadataInsightResourceCapacityTrendAggregatedRequest
     * @return SummarizeExadataInsightResourceCapacityTrendAggregatedResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeExadataInsightResourceCapacityTrendAggregated.ts.html |here} to see how to use SummarizeExadataInsightResourceCapacityTrendAggregated API.
     */
    summarizeExadataInsightResourceCapacityTrendAggregated(summarizeExadataInsightResourceCapacityTrendAggregatedRequest: requests.SummarizeExadataInsightResourceCapacityTrendAggregatedRequest): Promise<responses.SummarizeExadataInsightResourceCapacityTrendAggregatedResponse>;
    /**
     * Get historical usage and forecast predictions for an exadata system with breakdown by databases, hosts or storage servers.
     * Additionally resources can be filtered using databaseInsightId, hostInsightId or storageServerName query parameters.
     * Top five resources are returned if total exceeds the limit specified.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE. Database name is returned in name field. DatabaseInsightId , cdbName and hostName query parameter applies to ResourceType DATABASE.
     * Valid values for ResourceType HOST are CPU and MEMORY. HostName s returned in name field. HostInsightId and hostName query parameter applies to ResourceType HOST.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT. Storage server name is returned in name field for resourceMetric IOPS and THROUGHPUT
     * and asmName is returned in name field for resourceMetric STORAGE. StorageServerName query parameter applies to ResourceType STORAGE_SERVER.
     * Valid value for ResourceType DISKGROUP is STORAGE. Comma delimited (asmName,diskgroupName) is returned in name field.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeExadataInsightResourceForecastTrendRequest
     * @return SummarizeExadataInsightResourceForecastTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeExadataInsightResourceForecastTrend.ts.html |here} to see how to use SummarizeExadataInsightResourceForecastTrend API.
     */
    summarizeExadataInsightResourceForecastTrend(summarizeExadataInsightResourceForecastTrendRequest: requests.SummarizeExadataInsightResourceForecastTrendRequest): Promise<responses.SummarizeExadataInsightResourceForecastTrendResponse>;
    /**
     * Get aggregated historical usage and forecast predictions for resources. Either compartmentId or exadataInsightsId query parameter must be specified.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeExadataInsightResourceForecastTrendAggregatedRequest
     * @return SummarizeExadataInsightResourceForecastTrendAggregatedResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeExadataInsightResourceForecastTrendAggregated.ts.html |here} to see how to use SummarizeExadataInsightResourceForecastTrendAggregated API.
     */
    summarizeExadataInsightResourceForecastTrendAggregated(summarizeExadataInsightResourceForecastTrendAggregatedRequest: requests.SummarizeExadataInsightResourceForecastTrendAggregatedRequest): Promise<responses.SummarizeExadataInsightResourceForecastTrendAggregatedResponse>;
    /**
     * Lists the Resource statistics (usage, capacity, usage change percent, utilization percent) for each resource based on resourceMetric filtered by utilization level.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS, THROUGHPUT.
     * Valid value for ResourceType DISKGROUP is STORAGE.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeExadataInsightResourceStatisticsRequest
     * @return SummarizeExadataInsightResourceStatisticsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeExadataInsightResourceStatistics.ts.html |here} to see how to use SummarizeExadataInsightResourceStatistics API.
     */
    summarizeExadataInsightResourceStatistics(summarizeExadataInsightResourceStatisticsRequest: requests.SummarizeExadataInsightResourceStatisticsRequest): Promise<responses.SummarizeExadataInsightResourceStatisticsResponse>;
    /**
     * A cumulative distribution function is used to rank the usage data points per resource within the specified time period.
     * For each resource, the minimum data point with a ranking > the percentile value is included in the summation.
     * Linear regression functions are used to calculate the usage change percentage.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeExadataInsightResourceUsageRequest
     * @return SummarizeExadataInsightResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeExadataInsightResourceUsage.ts.html |here} to see how to use SummarizeExadataInsightResourceUsage API.
     */
    summarizeExadataInsightResourceUsage(summarizeExadataInsightResourceUsageRequest: requests.SummarizeExadataInsightResourceUsageRequest): Promise<responses.SummarizeExadataInsightResourceUsageResponse>;
    /**
     * A cumulative distribution function is used to rank the usage data points per database within the specified time period.
     * For each database, the minimum data point with a ranking > the percentile value is included in the summation.
     * Linear regression functions are used to calculate the usage change percentage.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeExadataInsightResourceUsageAggregatedRequest
     * @return SummarizeExadataInsightResourceUsageAggregatedResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeExadataInsightResourceUsageAggregated.ts.html |here} to see how to use SummarizeExadataInsightResourceUsageAggregated API.
     */
    summarizeExadataInsightResourceUsageAggregated(summarizeExadataInsightResourceUsageAggregatedRequest: requests.SummarizeExadataInsightResourceUsageAggregatedRequest): Promise<responses.SummarizeExadataInsightResourceUsageAggregatedResponse>;
    /**
     * Gets current utilization, projected utilization and days to reach projectedUtilization for an exadata system over specified time period. Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE. Valid values for ResourceType HOST are CPU and MEMORY. Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeExadataInsightResourceUtilizationInsightRequest
     * @return SummarizeExadataInsightResourceUtilizationInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeExadataInsightResourceUtilizationInsight.ts.html |here} to see how to use SummarizeExadataInsightResourceUtilizationInsight API.
     */
    summarizeExadataInsightResourceUtilizationInsight(summarizeExadataInsightResourceUtilizationInsightRequest: requests.SummarizeExadataInsightResourceUtilizationInsightRequest): Promise<responses.SummarizeExadataInsightResourceUtilizationInsightResponse>;
    /**
     * Lists the software and hardware inventory of the Exadata System.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeExadataMembersRequest
     * @return SummarizeExadataMembersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeExadataMembers.ts.html |here} to see how to use SummarizeExadataMembers API.
     */
    summarizeExadataMembers(summarizeExadataMembersRequest: requests.SummarizeExadataMembersRequest): Promise<responses.SummarizeExadataMembersResponse>;
    /**
     * Returns response with time series data (endTimestamp, capacity) for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeHostInsightResourceCapacityTrendRequest
     * @return SummarizeHostInsightResourceCapacityTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeHostInsightResourceCapacityTrend.ts.html |here} to see how to use SummarizeHostInsightResourceCapacityTrend API.
     */
    summarizeHostInsightResourceCapacityTrend(summarizeHostInsightResourceCapacityTrendRequest: requests.SummarizeHostInsightResourceCapacityTrendRequest): Promise<responses.SummarizeHostInsightResourceCapacityTrendResponse>;
    /**
     * Get Forecast predictions for CPU or memory resources since a time in the past.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeHostInsightResourceForecastTrendRequest
     * @return SummarizeHostInsightResourceForecastTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeHostInsightResourceForecastTrend.ts.html |here} to see how to use SummarizeHostInsightResourceForecastTrend API.
     */
    summarizeHostInsightResourceForecastTrend(summarizeHostInsightResourceForecastTrendRequest: requests.SummarizeHostInsightResourceForecastTrendRequest): Promise<responses.SummarizeHostInsightResourceForecastTrendResponse>;
    /**
     * Lists the resource statistics (usage, capacity, usage change percent, utilization percent, load) for each host filtered
     * by utilization level in a compartment and in all sub-compartments if specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeHostInsightResourceStatisticsRequest
     * @return SummarizeHostInsightResourceStatisticsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeHostInsightResourceStatistics.ts.html |here} to see how to use SummarizeHostInsightResourceStatistics API.
     */
    summarizeHostInsightResourceStatistics(summarizeHostInsightResourceStatisticsRequest: requests.SummarizeHostInsightResourceStatisticsRequest): Promise<responses.SummarizeHostInsightResourceStatisticsResponse>;
    /**
     * A cumulative distribution function is used to rank the usage data points per host within the specified time period.
     * For each host, the minimum data point with a ranking > the percentile value is included in the summation.
     * Linear regression functions are used to calculate the usage change percentage.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeHostInsightResourceUsageRequest
     * @return SummarizeHostInsightResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeHostInsightResourceUsage.ts.html |here} to see how to use SummarizeHostInsightResourceUsage API.
     */
    summarizeHostInsightResourceUsage(summarizeHostInsightResourceUsageRequest: requests.SummarizeHostInsightResourceUsageRequest): Promise<responses.SummarizeHostInsightResourceUsageResponse>;
    /**
     * Returns response with time series data (endTimestamp, usage, capacity) for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeHostInsightResourceUsageTrendRequest
     * @return SummarizeHostInsightResourceUsageTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeHostInsightResourceUsageTrend.ts.html |here} to see how to use SummarizeHostInsightResourceUsageTrend API.
     */
    summarizeHostInsightResourceUsageTrend(summarizeHostInsightResourceUsageTrendRequest: requests.SummarizeHostInsightResourceUsageTrendRequest): Promise<responses.SummarizeHostInsightResourceUsageTrendResponse>;
    /**
     * Gets resources with current utilization (high and low) and projected utilization (high and low) for a resource type over specified time period.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeHostInsightResourceUtilizationInsightRequest
     * @return SummarizeHostInsightResourceUtilizationInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeHostInsightResourceUtilizationInsight.ts.html |here} to see how to use SummarizeHostInsightResourceUtilizationInsight API.
     */
    summarizeHostInsightResourceUtilizationInsight(summarizeHostInsightResourceUtilizationInsightRequest: requests.SummarizeHostInsightResourceUtilizationInsightRequest): Promise<responses.SummarizeHostInsightResourceUtilizationInsightResponse>;
    /**
     * Gets the details of resources used by an Operations Insights Warehouse.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeOperationsInsightsWarehouseResourceUsageRequest
     * @return SummarizeOperationsInsightsWarehouseResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeOperationsInsightsWarehouseResourceUsage.ts.html |here} to see how to use SummarizeOperationsInsightsWarehouseResourceUsage API.
     */
    summarizeOperationsInsightsWarehouseResourceUsage(summarizeOperationsInsightsWarehouseResourceUsageRequest: requests.SummarizeOperationsInsightsWarehouseResourceUsageRequest): Promise<responses.SummarizeOperationsInsightsWarehouseResourceUsageResponse>;
    /**
     * Query SQL Warehouse to get the performance insights for SQLs taking greater than X% database time for a given
     * time period across the given databases or database types in a compartment and in all sub-compartments if specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeSqlInsightsRequest
     * @return SummarizeSqlInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeSqlInsights.ts.html |here} to see how to use SummarizeSqlInsights API.
     */
    summarizeSqlInsights(summarizeSqlInsightsRequest: requests.SummarizeSqlInsightsRequest): Promise<responses.SummarizeSqlInsightsResponse>;
    /**
     * Query SQL Warehouse to get the performance insights on the execution plans for a given SQL for a given time period.
     * Either databaseId or id must be specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeSqlPlanInsightsRequest
     * @return SummarizeSqlPlanInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeSqlPlanInsights.ts.html |here} to see how to use SummarizeSqlPlanInsights API.
     */
    summarizeSqlPlanInsights(summarizeSqlPlanInsightsRequest: requests.SummarizeSqlPlanInsightsRequest): Promise<responses.SummarizeSqlPlanInsightsResponse>;
    /**
     * Query SQL Warehouse to summarize the response time distribution of query executions for a given SQL for a given time period.
     * Either databaseId or id must be specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeSqlResponseTimeDistributionsRequest
     * @return SummarizeSqlResponseTimeDistributionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeSqlResponseTimeDistributions.ts.html |here} to see how to use SummarizeSqlResponseTimeDistributions API.
     */
    summarizeSqlResponseTimeDistributions(summarizeSqlResponseTimeDistributionsRequest: requests.SummarizeSqlResponseTimeDistributionsRequest): Promise<responses.SummarizeSqlResponseTimeDistributionsResponse>;
    /**
     * Query SQL Warehouse to get the performance statistics for SQLs taking greater than X% database time for a given
     * time period across the given databases or database types in a compartment and in all sub-compartments if specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeSqlStatisticsRequest
     * @return SummarizeSqlStatisticsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeSqlStatistics.ts.html |here} to see how to use SummarizeSqlStatistics API.
     */
    summarizeSqlStatistics(summarizeSqlStatisticsRequest: requests.SummarizeSqlStatisticsRequest): Promise<responses.SummarizeSqlStatisticsResponse>;
    /**
     * Query SQL Warehouse to get the performance statistics time series for a given SQL across given databases for a
     * given time period in a compartment and in all sub-compartments if specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeSqlStatisticsTimeSeriesRequest
     * @return SummarizeSqlStatisticsTimeSeriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeSqlStatisticsTimeSeries.ts.html |here} to see how to use SummarizeSqlStatisticsTimeSeries API.
     */
    summarizeSqlStatisticsTimeSeries(summarizeSqlStatisticsTimeSeriesRequest: requests.SummarizeSqlStatisticsTimeSeriesRequest): Promise<responses.SummarizeSqlStatisticsTimeSeriesResponse>;
    /**
     * Query SQL Warehouse to get the performance statistics time series for a given SQL by execution plans for a given time period.
     * Either databaseId or id must be specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SummarizeSqlStatisticsTimeSeriesByPlanRequest
     * @return SummarizeSqlStatisticsTimeSeriesByPlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/SummarizeSqlStatisticsTimeSeriesByPlan.ts.html |here} to see how to use SummarizeSqlStatisticsTimeSeriesByPlan API.
     */
    summarizeSqlStatisticsTimeSeriesByPlan(summarizeSqlStatisticsTimeSeriesByPlanRequest: requests.SummarizeSqlStatisticsTimeSeriesByPlanRequest): Promise<responses.SummarizeSqlStatisticsTimeSeriesByPlanResponse>;
    /**
     * Updates the configuration of a hub .
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateAwrHubRequest
     * @return UpdateAwrHubResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/UpdateAwrHub.ts.html |here} to see how to use UpdateAwrHub API.
     */
    updateAwrHub(updateAwrHubRequest: requests.UpdateAwrHubRequest): Promise<responses.UpdateAwrHubResponse>;
    /**
     * Updates configuration of a database insight.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDatabaseInsightRequest
     * @return UpdateDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/UpdateDatabaseInsight.ts.html |here} to see how to use UpdateDatabaseInsight API.
     */
    updateDatabaseInsight(updateDatabaseInsightRequest: requests.UpdateDatabaseInsightRequest): Promise<responses.UpdateDatabaseInsightResponse>;
    /**
     * Updates configuration of an Operations Insights Enterprise Manager bridge.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateEnterpriseManagerBridgeRequest
     * @return UpdateEnterpriseManagerBridgeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/UpdateEnterpriseManagerBridge.ts.html |here} to see how to use UpdateEnterpriseManagerBridge API.
     */
    updateEnterpriseManagerBridge(updateEnterpriseManagerBridgeRequest: requests.UpdateEnterpriseManagerBridgeRequest): Promise<responses.UpdateEnterpriseManagerBridgeResponse>;
    /**
     * Updates configuration of an Exadata insight.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateExadataInsightRequest
     * @return UpdateExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/UpdateExadataInsight.ts.html |here} to see how to use UpdateExadataInsight API.
     */
    updateExadataInsight(updateExadataInsightRequest: requests.UpdateExadataInsightRequest): Promise<responses.UpdateExadataInsightResponse>;
    /**
     * Updates configuration of a host insight.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateHostInsightRequest
     * @return UpdateHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/UpdateHostInsight.ts.html |here} to see how to use UpdateHostInsight API.
     */
    updateHostInsight(updateHostInsightRequest: requests.UpdateHostInsightRequest): Promise<responses.UpdateHostInsightResponse>;
    /**
     * Updates the configuration of an Operations Insights Warehouse.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateOperationsInsightsWarehouseRequest
     * @return UpdateOperationsInsightsWarehouseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/UpdateOperationsInsightsWarehouse.ts.html |here} to see how to use UpdateOperationsInsightsWarehouse API.
     */
    updateOperationsInsightsWarehouse(updateOperationsInsightsWarehouseRequest: requests.UpdateOperationsInsightsWarehouseRequest): Promise<responses.UpdateOperationsInsightsWarehouseResponse>;
    /**
     * Updates the configuration of an Operations Insights Warehouse User.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateOperationsInsightsWarehouseUserRequest
     * @return UpdateOperationsInsightsWarehouseUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/opsi/UpdateOperationsInsightsWarehouseUser.ts.html |here} to see how to use UpdateOperationsInsightsWarehouseUser API.
     */
    updateOperationsInsightsWarehouseUser(updateOperationsInsightsWarehouseUserRequest: requests.UpdateOperationsInsightsWarehouseUserRequest): Promise<responses.UpdateOperationsInsightsWarehouseUserResponse>;
}
