/**
 * Billing Center Gateway API
 * This site describes all the Rest endpoints of Billing Center Gateway.
 * OpenAPI spec version: 20191001
 * Contact: osp_team_oci_cam_ww_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
export declare enum InvoiceServiceApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class InvoiceServiceClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Returns an invoice in pdf format
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DownloadPdfContentRequest
     * @return DownloadPdfContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/ospgateway/DownloadPdfContent.ts.html |here} to see how to use DownloadPdfContent API.
     */
    downloadPdfContent(downloadPdfContentRequest: requests.DownloadPdfContentRequest): Promise<responses.DownloadPdfContentResponse>;
    /**
     * Returns an invoice by invoice id
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetInvoiceRequest
     * @return GetInvoiceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/ospgateway/GetInvoice.ts.html |here} to see how to use GetInvoice API.
     */
    getInvoice(getInvoiceRequest: requests.GetInvoiceRequest): Promise<responses.GetInvoiceResponse>;
    /**
     * Returns the invoice product list by invoice id
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListInvoiceLinesRequest
     * @return ListInvoiceLinesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/ospgateway/ListInvoiceLines.ts.html |here} to see how to use ListInvoiceLines API.
     */
    listInvoiceLines(listInvoiceLinesRequest: requests.ListInvoiceLinesRequest): Promise<responses.ListInvoiceLinesResponse>;
    /**
     * Returns a list of invoices
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListInvoicesRequest
     * @return ListInvoicesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/ospgateway/ListInvoices.ts.html |here} to see how to use ListInvoices API.
     */
    listInvoices(listInvoicesRequest: requests.ListInvoicesRequest): Promise<responses.ListInvoicesResponse>;
    /**
     * Pay an invoice
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param PayInvoiceRequest
     * @return PayInvoiceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.12.0/ospgateway/PayInvoice.ts.html |here} to see how to use PayInvoice API.
     */
    payInvoice(payInvoiceRequest: requests.PayInvoiceRequest): Promise<responses.PayInvoiceResponse>;
}
